var SHA1 = (function(){
//
// A JavaScript implementation of the Secure Hash Algorithm, SHA-1, as defined
// in FIPS PUB 180-1
// Version 2.1a Copyright Paul Johnston 2000 - 2002.
// Other contributors: Greg Holt, Andrew Kepert, Ydnar, Lostinet
// Distributed under the BSD License
// See http://pajhome.org.uk/crypt/md5 for details.
//

//
// Configurable variables. You may need to tweak these to be compatible with
// the server-side, but the defaults work in most cases.
//

// hex output format. 0 - lowercase; 1 - uppercase
var hexcase = 0, b64pad  = "", chrsz   = 8,

// These are the functions you'll usually want to call
// They take string arguments and return either hex or base-64 encoded strings
hex_sha1 = function(s){return binb2hex(core_sha1(str2binb(s),s.length * chrsz));},
b64_sha1 = function(s){return binb2b64(core_sha1(str2binb(s),s.length * chrsz));},
str_sha1 = function(s){return binb2str(core_sha1(str2binb(s),s.length * chrsz));},
hex_hmac_sha1 = function(key, data){ return binb2hex(core_hmac_sha1(key, data));},
b64_hmac_sha1 = function(key, data){ return binb2b64(core_hmac_sha1(key, data));},
str_hmac_sha1 = function(key, data){ return binb2str(core_hmac_sha1(key, data));},

//Perform a simple self-test to see if the VM is working
sha1_vm_test = function(){ return hex_sha1("abc") == "a9993e364706816aba3e25717850c26c9cd0d89d";},

// Calculate the SHA-1 of an array of big-endian words, and a bit length
core_sha1 = function(x, len) 
{
  // append padding
  x[len >> 5] |= 0x80 << (24 - len % 32);
  x[((len + 64 >> 9) << 4) + 15] = len;

  var w = Array(80);
  var a =  1732584193;
  var b = -271733879;
  var c = -1732584194;
  var d =  271733878;
  var e = -1009589776;

  for(var i = 0; i < x.length; i += 16)
  {
    var olda = a;
    var oldb = b;
    var oldc = c;
    var oldd = d;
    var olde = e;

    for(var j = 0; j < 80; j++)
    {
      if(j < 16) w[j] = x[i + j];
      else w[j] = rol(w[j-3] ^ w[j-8] ^ w[j-14] ^ w[j-16], 1);
      var t = safe_add(safe_add(rol(a, 5), sha1_ft(j, b, c, d)),
                       safe_add(safe_add(e, w[j]), sha1_kt(j)));
      e = d;
      d = c;
      c = rol(b, 30);
      b = a;
      a = t;
    }

    a = safe_add(a, olda);
    b = safe_add(b, oldb);
    c = safe_add(c, oldc);
    d = safe_add(d, oldd);
    e = safe_add(e, olde);
  }
  return Array(a, b, c, d, e);

},

// Perform the appropriate triplet combination function for the current
// iteration
sha1_ft = function(t, b, c, d)
{
  if(t < 20) return (b & c) | ((~b) & d);
  if(t < 40) return b ^ c ^ d;
  if(t < 60) return (b & c) | (b & d) | (c & d);
  return b ^ c ^ d;
},

// Determine the appropriate additive constant for the current iteration
sha1_kt = function(t)
{
  return (t < 20) ?  1518500249 : (t < 40) ?  1859775393 :
         (t < 60) ? -1894007588 : -899497514;
},

// Calculate the HMAC-SHA1 of a key and some data
core_hmac_sha1 = function(key, data)
{
  var bkey = str2binb(key);
  if(bkey.length > 16) bkey = core_sha1(bkey, key.length * chrsz);

  var ipad = Array(16), opad = Array(16);
  for(var i = 0; i < 16; i++)
  {
    ipad[i] = bkey[i] ^ 0x36363636;
    opad[i] = bkey[i] ^ 0x5C5C5C5C;
  }

  var hash = core_sha1(ipad.concat(str2binb(data)), 512 + data.length * chrsz);
  return core_sha1(opad.concat(hash), 512 + 160);
},

// Add integers, wrapping at 2^32. This uses 16-bit operations internally
// to work around bugs in some JS interpreters.
safe_add = function(x, y)
{
  var lsw = (x & 0xFFFF) + (y & 0xFFFF);
  var msw = (x >> 16) + (y >> 16) + (lsw >> 16);
  return (msw << 16) | (lsw & 0xFFFF);
},

// Bitwise rotate a 32-bit number to the left.
rol = function(num, cnt)
{
  return (num << cnt) | (num >>> (32 - cnt));
},

// Convert an 8-bit or 16-bit string to an array of big-endian words
// In 8-bit function, characters >255 have their hi-byte silently ignored.
str2binb = function(str)
{
  var bin = Array();
  var mask = (1 << chrsz) - 1;
  for(var i = 0; i < str.length * chrsz; i += chrsz)
    bin[i>>5] |= (str.charCodeAt(i / chrsz) & mask) << (32 - chrsz - i%32);
  return bin;
},

// Convert an array of big-endian words to a string
binb2str = function (bin)
{
  var str = "";
  var mask = (1 << chrsz) - 1;
  for(var i = 0; i < bin.length * 32; i += chrsz)
    str += String.fromCharCode((bin[i>>5] >>> (32 - chrsz - i%32)) & mask);
  return str;
},

// Convert an array of big-endian words to a hex string.
binb2hex = function(binarray)
{
  var hex_tab = hexcase ? "0123456789ABCDEF" : "0123456789abcdef";
  var str = "";
  for(var i = 0; i < binarray.length * 4; i++)
  {
    str += hex_tab.charAt((binarray[i>>2] >> ((3 - i%4)*8+4)) & 0xF) +
           hex_tab.charAt((binarray[i>>2] >> ((3 - i%4)*8  )) & 0xF);
  }
  return str;
},

hex2bin = function(hex_str)
{
	var char_str = "";
	var num_str = "";
	var i;
	for(i=0; i < hex_str.length; i+=2) {
		char_str += String.fromCharCode(parseInt(hex_str.substring(i, i+2), 16));
	}
	return char_str;
},

// Convert an array of big-endian words to a base-64 string
binb2b64 = function(binarray)
{
  var tab = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
  var str = "";
  for(var i = 0; i < binarray.length * 4; i += 3)
  {
    var triplet = (((binarray[i   >> 2] >> 8 * (3 -  i   %4)) & 0xFF) << 16)
                | (((binarray[i+1 >> 2] >> 8 * (3 - (i+1)%4)) & 0xFF) << 8 )
                |  ((binarray[i+2 >> 2] >> 8 * (3 - (i+2)%4)) & 0xFF);
    for(var j = 0; j < 4; j++)
    {
      if(i * 8 + j * 6 > binarray.length * 32) str += b64pad;
      else str += tab.charAt((triplet >> 6*(3-j)) & 0x3F);
    }
  }
  return str;
};

    return {
        "hex2bin":hex2bin,
        "binb2hex":binb2hex,
		"core_sha1":core_sha1,
		"str2binb":str2binb
    };
})();

var SHA256 = (function(){
/*
* A JavaScript implementation of the SHA256 hash function.
*
* FILE:	sha256.js
* VERSION:	0.8
* AUTHOR:	Christoph Bichlmeier <informatik@zombiearena.de>
*
* NOTE: This version is not tested thoroughly!
*
* Copyright (c) 2003, Christoph Bichlmeier
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions
* are met:
* 1. Redistributions of source code must retain the above copyright
*    notice, this list of conditions and the following disclaimer.
* 2. Redistributions in binary form must reproduce the above copyright
*    notice, this list of conditions and the following disclaimer in the
*    documentation and/or other materials provided with the distribution.
* 3. Neither the name of the copyright holder nor the names of contributors
*    may be used to endorse or promote products derived from this software
*    without specific prior written permission.
*
* ======================================================================
*
* THIS SOFTWARE IS PROVIDED BY THE AUTHORS ''AS IS'' AND ANY EXPRESS
* OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
* ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE
* LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
* CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
* SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
* BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
* WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
* OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
* EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

var ihash, count, buffer,
sha256_hex_digits = "0123456789abcdef",

/* SHA256 logical functions */
rotateRight = function(n,x) {
	return ((x >>> n) | (x << (32 - n)));
},
choice = function(x,y,z) {
	return ((x & y) ^ (~x & z));
},
majority = function(x,y,z) {
	return ((x & y) ^ (x & z) ^ (y & z));
},
sha256_Sigma0 = function(x) {
	return (rotateRight(2, x) ^ rotateRight(13, x) ^ rotateRight(22, x));
},
sha256_Sigma1 = function(x) {
	return (rotateRight(6, x) ^ rotateRight(11, x) ^ rotateRight(25, x));
},
sha256_sigma0 = function(x) {
	return (rotateRight(7, x) ^ rotateRight(18, x) ^ (x >>> 3));
},
sha256_sigma1 = function(x) {
	return (rotateRight(17, x) ^ rotateRight(19, x) ^ (x >>> 10));
},
sha256_expand = function(W, j) {
	return (W[j&0x0f] += sha256_sigma1(W[(j+14)&0x0f]) + W[(j+9)&0x0f] + 
sha256_sigma0(W[(j+1)&0x0f]));
},

/* Hash constant words K: */
K256 = new Array(
	0x428a2f98, 0x71374491, 0xb5c0fbcf, 0xe9b5dba5,
	0x3956c25b, 0x59f111f1, 0x923f82a4, 0xab1c5ed5,
	0xd807aa98, 0x12835b01, 0x243185be, 0x550c7dc3,
	0x72be5d74, 0x80deb1fe, 0x9bdc06a7, 0xc19bf174,
	0xe49b69c1, 0xefbe4786, 0x0fc19dc6, 0x240ca1cc,
	0x2de92c6f, 0x4a7484aa, 0x5cb0a9dc, 0x76f988da,
	0x983e5152, 0xa831c66d, 0xb00327c8, 0xbf597fc7,
	0xc6e00bf3, 0xd5a79147, 0x06ca6351, 0x14292967,
	0x27b70a85, 0x2e1b2138, 0x4d2c6dfc, 0x53380d13,
	0x650a7354, 0x766a0abb, 0x81c2c92e, 0x92722c85,
	0xa2bfe8a1, 0xa81a664b, 0xc24b8b70, 0xc76c51a3,
	0xd192e819, 0xd6990624, 0xf40e3585, 0x106aa070,
	0x19a4c116, 0x1e376c08, 0x2748774c, 0x34b0bcb5,
	0x391c0cb3, 0x4ed8aa4a, 0x5b9cca4f, 0x682e6ff3,
	0x748f82ee, 0x78a5636f, 0x84c87814, 0x8cc70208,
	0x90befffa, 0xa4506ceb, 0xbef9a3f7, 0xc67178f2
),

/* Add 32-bit integers with 16-bit operations (bug in some JS-interpreters: 
overflow) */
safe_add = function(x, y)
{
	var lsw = (x & 0xffff) + (y & 0xffff);
	var msw = (x >> 16) + (y >> 16) + (lsw >> 16);
	return (msw << 16) | (lsw & 0xffff);
},

/* Initialise the SHA256 computation */
sha256_init = function() {
	ihash = new Array(8);
	count = new Array(2);
	buffer = new Array(64);
	count[0] = count[1] = 0;
	ihash[0] = 0x6a09e667;
	ihash[1] = 0xbb67ae85;
	ihash[2] = 0x3c6ef372;
	ihash[3] = 0xa54ff53a;
	ihash[4] = 0x510e527f;
	ihash[5] = 0x9b05688c;
	ihash[6] = 0x1f83d9ab;
	ihash[7] = 0x5be0cd19;
},

/* Transform a 512-bit message block */
sha256_transform = function() {
	var a, b, c, d, e, f, g, h, T1, T2;
	var W = new Array(16);

	/* Initialize registers with the previous intermediate value */
	a = ihash[0];
	b = ihash[1];
	c = ihash[2];
	d = ihash[3];
	e = ihash[4];
	f = ihash[5];
	g = ihash[6];
	h = ihash[7];

        /* make 32-bit words */
	for(var i=0; i<16; i++)
		W[i] = ((buffer[(i<<2)+3]) | (buffer[(i<<2)+2] << 8) | (buffer[(i<<2)+1] << 16) | (buffer[i<<2] << 24));

        for(var j=0; j<64; j++) {
		T1 = h + sha256_Sigma1(e) + choice(e, f, g) + K256[j];
		if(j < 16) T1 += W[j];
		else T1 += sha256_expand(W, j);
		T2 = sha256_Sigma0(a) + majority(a, b, c);
		h = g;
		g = f;
		f = e;
		e = safe_add(d, T1);
		d = c;
		c = b;
		b = a;
		a = safe_add(T1, T2);
        }

	/* Compute the current intermediate hash value */
	ihash[0] += a;
	ihash[1] += b;
	ihash[2] += c;
	ihash[3] += d;
	ihash[4] += e;
	ihash[5] += f;
	ihash[6] += g;
	ihash[7] += h;
},

/* Read the next chunk of data and update the SHA256 computation */
sha256_update = function(data, inputLen) {
	var i, index, curpos = 0;
	/* Compute number of bytes mod 64 */
	index = ((count[0] >> 3) & 0x3f);
        var remainder = (inputLen & 0x3f);

	/* Update number of bits */
	if ((count[0] += (inputLen << 3)) < (inputLen << 3)) count[1]++;
	count[1] += (inputLen >> 29);

	/* Transform as many times as possible */
	for(i=0; i+63<inputLen; i+=64) {
                for(var j=index; j<64; j++)
			buffer[j] = data.charCodeAt(curpos++);
		sha256_transform();
		index = 0;
	}

	/* Buffer remaining input */
	for(var j=0; j<remainder; j++)
		buffer[j] = data.charCodeAt(curpos++);
},

/* Finish the computation by operations such as padding */
sha256_final = function() {
	var index = ((count[0] >> 3) & 0x3f);
        buffer[index++] = 0x80;
        if(index <= 56) {
		for(var i=index; i<56; i++)
			buffer[i] = 0;
        } else {
		for(var i=index; i<64; i++)
			buffer[i] = 0;
                sha256_transform();
                for(var i=0; i<56; i++)
			buffer[i] = 0;
	}
        buffer[56] = (count[1] >>> 24) & 0xff;
        buffer[57] = (count[1] >>> 16) & 0xff;
        buffer[58] = (count[1] >>> 8) & 0xff;
        buffer[59] = count[1] & 0xff;
        buffer[60] = (count[0] >>> 24) & 0xff;
        buffer[61] = (count[0] >>> 16) & 0xff;
        buffer[62] = (count[0] >>> 8) & 0xff;
        buffer[63] = count[0] & 0xff;
        sha256_transform();
},

/* Split the internal hash values into an array of bytes */
sha256_encode_bytes = function() {
        var j=0;
        var output = new Array(32);
	for(var i=0; i<8; i++) {
		output[j++] = ((ihash[i] >>> 24) & 0xff);
		output[j++] = ((ihash[i] >>> 16) & 0xff);
		output[j++] = ((ihash[i] >>> 8) & 0xff);
		output[j++] = (ihash[i] & 0xff);
	}
	return output;
},

/* Get the internal hash as a hex string */
sha256_encode_hex = function() {
	var output = new String();
	for(var i=0; i<8; i++) {
		for(var j=28; j>=0; j-=4)
			output += sha256_hex_digits.charAt((ihash[i] >>> j) & 0x0f);
	}
	return output;
},

/* Main function: returns a hex string representing the SHA256 value of the 
given data */
sha256_digest = function(data) {
	sha256_init();
	sha256_update(data, data.length);
	sha256_final();
        return sha256_encode_hex();
},

/* test if the JS-interpreter is working properly */
sha256_self_test = function()
{
	return sha256_digest("message digest") == 
"f7846f55cf23e14eebeab5b4e1550cad5b509e3348fbc4efa3a1413d393cb650";
};

return {
	"sha256_digest": sha256_digest,
	"sha256_self_test": sha256_self_test
};
})();
"use strict";var sjcl={cipher:{},hash:{},keyexchange:{},mode:{},misc:{},codec:{},exception:{corrupt:function(a){this.toString=function(){return"CORRUPT: "+this.message};this.message=a},invalid:function(a){this.toString=function(){return"INVALID: "+this.message};this.message=a},bug:function(a){this.toString=function(){return"BUG: "+this.message};this.message=a},notReady:function(a){this.toString=function(){return"NOT READY: "+this.message};this.message=a}}};
sjcl.cipher.aes=function(a){this.o[0][0][0]||this.r();var b,c,d,e,f=this.o[0][4],g=this.o[1];b=a.length;var h=1;if(b!==4&&b!==6&&b!==8)throw new sjcl.exception.invalid("invalid aes key size");this.d=[d=a.slice(0),e=[]];for(a=b;a<4*b+28;a++){c=d[a-1];if(a%b===0||b===8&&a%b===4){c=f[c>>>24]<<24^f[c>>16&255]<<16^f[c>>8&255]<<8^f[c&255];if(a%b===0){c=c<<8^c>>>24^h<<24;h=h<<1^(h>>7)*283}}d[a]=d[a-b]^c}for(b=0;a;b++,a--){c=d[b&3?a:a-4];e[b]=a<=4||b<4?c:g[0][f[c>>>24]]^g[1][f[c>>16&255]]^g[2][f[c>>8&255]]^
g[3][f[c&255]]}};
sjcl.cipher.aes.prototype={encrypt:function(a){return this.N(a,0)},decrypt:function(a){return this.N(a,1)},o:[[[],[],[],[],[]],[[],[],[],[],[]]],r:function(){var a=this.o[0],b=this.o[1],c=a[4],d=b[4],e,f,g,h=[],i=[],k,j,l,m;for(e=0;e<0x100;e++)i[(h[e]=e<<1^(e>>7)*283)^e]=e;for(f=g=0;!c[f];f^=k||1,g=i[g]||1){l=g^g<<1^g<<2^g<<3^g<<4;l=l>>8^l&255^99;c[f]=l;d[l]=f;j=h[e=h[k=h[f]]];m=j*0x1010101^e*0x10001^k*0x101^f*0x1010100;j=h[l]*0x101^l*0x1010100;for(e=0;e<4;e++){a[e][f]=j=j<<24^j>>>8;b[e][l]=m=m<<24^m>>>8}}for(e=
0;e<5;e++){a[e]=a[e].slice(0);b[e]=b[e].slice(0)}},N:function(a,b){if(a.length!==4)throw new sjcl.exception.invalid("invalid aes block size");var c=this.d[b],d=a[0]^c[0],e=a[b?3:1]^c[1],f=a[2]^c[2];a=a[b?1:3]^c[3];var g,h,i,k=c.length/4-2,j,l=4,m=[0,0,0,0];g=this.o[b];var n=g[0],o=g[1],p=g[2],q=g[3],r=g[4];for(j=0;j<k;j++){g=n[d>>>24]^o[e>>16&255]^p[f>>8&255]^q[a&255]^c[l];h=n[e>>>24]^o[f>>16&255]^p[a>>8&255]^q[d&255]^c[l+1];i=n[f>>>24]^o[a>>16&255]^p[d>>8&255]^q[e&255]^c[l+2];a=n[a>>>24]^o[d>>16&
255]^p[e>>8&255]^q[f&255]^c[l+3];l+=4;d=g;e=h;f=i}for(j=0;j<4;j++){m[b?3&-j:j]=r[d>>>24]<<24^r[e>>16&255]<<16^r[f>>8&255]<<8^r[a&255]^c[l++];g=d;d=e;e=f;f=a;a=g}return m}};
sjcl.bitArray={bitSlice:function(a,b,c){a=sjcl.bitArray.T(a.slice(b/32),32-(b&31)).slice(1);return c===undefined?a:sjcl.bitArray.clamp(a,c-b)},extract:function(a,b,c){var d=Math.floor(-b-c&31);return((b+c-1^b)&-32?a[b/32|0]<<32-d^a[b/32+1|0]>>>d:a[b/32|0]>>>d)&(1<<c)-1},concat:function(a,b){if(a.length===0||b.length===0)return a.concat(b);var c=a[a.length-1],d=sjcl.bitArray.getPartial(c);return d===32?a.concat(b):sjcl.bitArray.T(b,d,c|0,a.slice(0,a.length-1))},bitLength:function(a){var b=a.length;
if(b===0)return 0;return(b-1)*32+sjcl.bitArray.getPartial(a[b-1])},clamp:function(a,b){if(a.length*32<b)return a;a=a.slice(0,Math.ceil(b/32));var c=a.length;b&=31;if(c>0&&b)a[c-1]=sjcl.bitArray.partial(b,a[c-1]&2147483648>>b-1,1);return a},partial:function(a,b,c){if(a===32)return b;return(c?b|0:b<<32-a)+a*0x10000000000},getPartial:function(a){return Math.round(a/0x10000000000)||32},equal:function(a,b){if(sjcl.bitArray.bitLength(a)!==sjcl.bitArray.bitLength(b))return false;var c=0,d;for(d=0;d<a.length;d++)c|=
a[d]^b[d];return c===0},T:function(a,b,c,d){var e;e=0;if(d===undefined)d=[];for(;b>=32;b-=32){d.push(c);c=0}if(b===0)return d.concat(a);for(e=0;e<a.length;e++){d.push(c|a[e]>>>b);c=a[e]<<32-b}e=a.length?a[a.length-1]:0;a=sjcl.bitArray.getPartial(e);d.push(sjcl.bitArray.partial(b+a&31,b+a>32?c:d.pop(),1));return d},k:function(a,b){return[a[0]^b[0],a[1]^b[1],a[2]^b[2],a[3]^b[3]]}};
sjcl.codec.utf8String={fromBits:function(a){var b="",c=sjcl.bitArray.bitLength(a),d,e;for(d=0;d<c/8;d++){if((d&3)===0)e=a[d/4];b+=String.fromCharCode(e>>>24);e<<=8}return decodeURIComponent(escape(b))},toBits:function(a){a=unescape(encodeURIComponent(a));var b=[],c,d=0;for(c=0;c<a.length;c++){d=d<<8|a.charCodeAt(c);if((c&3)===3){b.push(d);d=0}}c&3&&b.push(sjcl.bitArray.partial(8*(c&3),d));return b}};
sjcl.codec.hex={fromBits:function(a){var b="",c;for(c=0;c<a.length;c++)b+=((a[c]|0)+0xf00000000000).toString(16).substr(4);return b.substr(0,sjcl.bitArray.bitLength(a)/4)},toBits:function(a){var b,c=[],d;a=a.replace(/\s|0x/g,"");d=a.length;a+="00000000";for(b=0;b<a.length;b+=8)c.push(parseInt(a.substr(b,8),16)^0);return sjcl.bitArray.clamp(c,d*4)}};
sjcl.codec.base64={K:"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/",fromBits:function(a,b){var c="",d,e=0,f=sjcl.codec.base64.K,g=0,h=sjcl.bitArray.bitLength(a);for(d=0;c.length*6<h;){c+=f.charAt((g^a[d]>>>e)>>>26);if(e<6){g=a[d]<<6-e;e+=26;d++}else{g<<=6;e-=6}}for(;c.length&3&&!b;)c+="=";return c},toBits:function(a){a=a.replace(/\s|=/g,"");var b=[],c,d=0,e=sjcl.codec.base64.K,f=0,g;for(c=0;c<a.length;c++){g=e.indexOf(a.charAt(c));if(g<0)throw new sjcl.exception.invalid("this isn't base64: '"+
a.charAt(c)+"', "+c+" -- "+a.length);if(d>26){d-=26;b.push(f^g>>>d);f=g<<32-d}else{d+=6;f^=g<<32-d}}d&56&&b.push(sjcl.bitArray.partial(d&56,f,1));return b}};sjcl.codec.bytes={fromBits:function(a){var b=[],c=sjcl.bitArray.bitLength(a),d,e;for(d=0;d<c/8;d++){if((d&3)===0)e=a[d/4];b.push(e>>>24);e<<=8}return b},toBits:function(a){var b=[],c,d=0;for(c=0;c<a.length;c++){d=d<<8|a[c];if((c&3)===3){b.push(d);d=0}}c&3&&b.push(sjcl.bitArray.partial(8*(c&3),d));return b}};
sjcl.hash.sha256=function(a){this.d[0]||this.r();if(a){this.c=a.c.slice(0);this.b=a.b.slice(0);this.a=a.a}else this.reset()};sjcl.hash.sha256.hash=function(a){return(new sjcl.hash.sha256).update(a).finalize()};
sjcl.hash.sha256.prototype={blockSize:512,reset:function(){this.c=this.l.slice(0);this.b=[];this.a=0;return this},update:function(a){if(typeof a==="string")a=sjcl.codec.utf8String.toBits(a);var b,c=this.b=sjcl.bitArray.concat(this.b,a);b=this.a;a=this.a=b+sjcl.bitArray.bitLength(a);for(b=512+b&-512;b<=a;b+=512)this.g(c.splice(0,16));return this},finalize:function(){var a,b=this.b,c=this.c;b=sjcl.bitArray.concat(b,[sjcl.bitArray.partial(1,1)]);for(a=b.length+2;a&15;a++)b.push(0);b.push(Math.floor(this.a/
4294967296));for(b.push(this.a|0);b.length;)this.g(b.splice(0,16));this.reset();return c},l:[],d:[],r:function(){function a(e){return(e-Math.floor(e))*0x100000000|0}var b=0,c=2,d;a:for(;b<64;c++){for(d=2;d*d<=c;d++)if(c%d===0)continue a;if(b<8)this.l[b]=a(Math.pow(c,0.5));this.d[b]=a(Math.pow(c,1/3));b++}},g:function(a){var b,c,d=a.slice(0),e=this.c,f=this.d,g=e[0],h=e[1],i=e[2],k=e[3],j=e[4],l=e[5],m=e[6],n=e[7];for(a=0;a<64;a++){if(a<16)b=d[a];else{b=d[a+1&15];c=d[a+14&15];b=d[a&15]=(b>>>7^b>>>18^
b>>>3^b<<25^b<<14)+(c>>>17^c>>>19^c>>>10^c<<15^c<<13)+d[a&15]+d[a+9&15]|0}b=b+n+(j>>>6^j>>>11^j>>>25^j<<26^j<<21^j<<7)+(m^j&(l^m))+f[a];n=m;m=l;l=j;j=k+b|0;k=i;i=h;h=g;g=b+(h&i^k&(h^i))+(h>>>2^h>>>13^h>>>22^h<<30^h<<19^h<<10)|0}e[0]=e[0]+g|0;e[1]=e[1]+h|0;e[2]=e[2]+i|0;e[3]=e[3]+k|0;e[4]=e[4]+j|0;e[5]=e[5]+l|0;e[6]=e[6]+m|0;e[7]=e[7]+n|0}};
sjcl.mode.ccm={name:"ccm",encrypt:function(a,b,c,d,e){var f,g=b.slice(0),h=sjcl.bitArray,i=h.bitLength(c)/8,k=h.bitLength(g)/8;e=e||64;d=d||[];if(i<7)throw new sjcl.exception.invalid("ccm: iv must be at least 7 bytes");for(f=2;f<4&&k>>>8*f;f++);if(f<15-i)f=15-i;c=h.clamp(c,8*(15-f));b=sjcl.mode.ccm.M(a,b,c,d,e,f);g=sjcl.mode.ccm.O(a,g,c,b,e,f);return h.concat(g.data,g.tag)},decrypt:function(a,b,c,d,e){e=e||64;d=d||[];var f=sjcl.bitArray,g=f.bitLength(c)/8,h=f.bitLength(b),i=f.clamp(b,h-e),k=f.bitSlice(b,
h-e);h=(h-e)/8;if(g<7)throw new sjcl.exception.invalid("ccm: iv must be at least 7 bytes");for(b=2;b<4&&h>>>8*b;b++);if(b<15-g)b=15-g;c=f.clamp(c,8*(15-b));i=sjcl.mode.ccm.O(a,i,c,k,e,b);a=sjcl.mode.ccm.M(a,i.data,c,d,e,b);if(!f.equal(i.tag,a))throw new sjcl.exception.corrupt("ccm: tag doesn't match");return i.data},M:function(a,b,c,d,e,f){var g=[],h=sjcl.bitArray,i=h.k;e/=8;if(e%2||e<4||e>16)throw new sjcl.exception.invalid("ccm: invalid tag length");if(d.length>0xffffffff||b.length>0xffffffff)throw new sjcl.exception.bug("ccm: can't deal with 4GiB or more data");
f=[h.partial(8,(d.length?64:0)|e-2<<2|f-1)];f=h.concat(f,c);f[3]|=h.bitLength(b)/8;f=a.encrypt(f);if(d.length){c=h.bitLength(d)/8;if(c<=65279)g=[h.partial(16,c)];else if(c<=0xffffffff)g=h.concat([h.partial(16,65534)],[c]);g=h.concat(g,d);for(d=0;d<g.length;d+=4)f=a.encrypt(i(f,g.slice(d,d+4).concat([0,0,0])))}for(d=0;d<b.length;d+=4)f=a.encrypt(i(f,b.slice(d,d+4).concat([0,0,0])));return h.clamp(f,e*8)},O:function(a,b,c,d,e,f){var g,h=sjcl.bitArray;g=h.k;var i=b.length,k=h.bitLength(b);c=h.concat([h.partial(8,
f-1)],c).concat([0,0,0]).slice(0,4);d=h.bitSlice(g(d,a.encrypt(c)),0,e);if(!i)return{tag:d,data:[]};for(g=0;g<i;g+=4){c[3]++;e=a.encrypt(c);b[g]^=e[0];b[g+1]^=e[1];b[g+2]^=e[2];b[g+3]^=e[3]}return{tag:d,data:h.clamp(b,k)}}};
sjcl.mode.ocb2={name:"ocb2",encrypt:function(a,b,c,d,e,f){if(sjcl.bitArray.bitLength(c)!==128)throw new sjcl.exception.invalid("ocb iv must be 128 bits");var g,h=sjcl.mode.ocb2.H,i=sjcl.bitArray,k=i.k,j=[0,0,0,0];c=h(a.encrypt(c));var l,m=[];d=d||[];e=e||64;for(g=0;g+4<b.length;g+=4){l=b.slice(g,g+4);j=k(j,l);m=m.concat(k(c,a.encrypt(k(c,l))));c=h(c)}l=b.slice(g);b=i.bitLength(l);g=a.encrypt(k(c,[0,0,0,b]));l=i.clamp(k(l.concat([0,0,0]),g),b);j=k(j,k(l.concat([0,0,0]),g));j=a.encrypt(k(j,k(c,h(c))));
if(d.length)j=k(j,f?d:sjcl.mode.ocb2.pmac(a,d));return m.concat(i.concat(l,i.clamp(j,e)))},decrypt:function(a,b,c,d,e,f){if(sjcl.bitArray.bitLength(c)!==128)throw new sjcl.exception.invalid("ocb iv must be 128 bits");e=e||64;var g=sjcl.mode.ocb2.H,h=sjcl.bitArray,i=h.k,k=[0,0,0,0],j=g(a.encrypt(c)),l,m,n=sjcl.bitArray.bitLength(b)-e,o=[];d=d||[];for(c=0;c+4<n/32;c+=4){l=i(j,a.decrypt(i(j,b.slice(c,c+4))));k=i(k,l);o=o.concat(l);j=g(j)}m=n-c*32;l=a.encrypt(i(j,[0,0,0,m]));l=i(l,h.clamp(b.slice(c),
m).concat([0,0,0]));k=i(k,l);k=a.encrypt(i(k,i(j,g(j))));if(d.length)k=i(k,f?d:sjcl.mode.ocb2.pmac(a,d));if(!h.equal(h.clamp(k,e),h.bitSlice(b,n)))throw new sjcl.exception.corrupt("ocb: tag doesn't match");return o.concat(h.clamp(l,m))},pmac:function(a,b){var c,d=sjcl.mode.ocb2.H,e=sjcl.bitArray,f=e.k,g=[0,0,0,0],h=a.encrypt([0,0,0,0]);h=f(h,d(d(h)));for(c=0;c+4<b.length;c+=4){h=d(h);g=f(g,a.encrypt(f(h,b.slice(c,c+4))))}b=b.slice(c);if(e.bitLength(b)<128){h=f(h,d(h));b=e.concat(b,[2147483648|0,0,
0,0])}g=f(g,b);return a.encrypt(f(d(f(h,d(h))),g))},H:function(a){return[a[0]<<1^a[1]>>>31,a[1]<<1^a[2]>>>31,a[2]<<1^a[3]>>>31,a[3]<<1^(a[0]>>>31)*135]}};sjcl.misc.hmac=function(a,b){this.p=b=b||sjcl.hash.sha256;var c=[[],[]],d=b.prototype.blockSize/32;this.e=[new b,new b];if(a.length>d)a=b.hash(a);for(b=0;b<d;b++){c[0][b]=a[b]^909522486;c[1][b]=a[b]^1549556828}this.e[0].update(c[0]);this.e[1].update(c[1])};
sjcl.misc.hmac.prototype.encrypt=sjcl.misc.hmac.prototype.mac=function(a,b){a=(new this.p(this.e[0])).update(a,b).finalize();return(new this.p(this.e[1])).update(a).finalize()};sjcl.hash.sha1=function(a){if(a){this.c=a.c.slice(0);this.b=a.b.slice(0);this.a=a.a}else this.reset()};sjcl.hash.sha1.hash=function(a){return(new sjcl.hash.sha1).update(a).finalize()};
sjcl.hash.sha1.prototype={blockSize:512,reset:function(){this.c=this.l.slice(0);this.b=[];this.a=0;return this},update:function(a){if(typeof a==="string")a=sjcl.codec.utf8String.toBits(a);var b,c=this.b=sjcl.bitArray.concat(this.b,a);b=this.a;a=this.a=b+sjcl.bitArray.bitLength(a);for(b=this.blockSize+b&-this.blockSize;b<=a;b+=this.blockSize)this.g(c.splice(0,16));return this},finalize:function(){var a,b=this.b,c=this.c;b=sjcl.bitArray.concat(b,[sjcl.bitArray.partial(1,1)]);for(a=b.length+2;a&15;a++)b.push(0);
b.push(Math.floor(this.a/0x100000000));for(b.push(this.a|0);b.length;)this.g(b.splice(0,16));this.reset();return c},l:[1732584193,4023233417,2562383102,271733878,3285377520],d:[1518500249,1859775393,2400959708,3395469782],X:function(a,b,c,d){if(a<=19)return b&c|~b&d;else if(a<=39)return b^c^d;else if(a<=59)return b&c|b&d|c&d;else if(a<=79)return b^c^d},z:function(a,b){return b<<a|b>>>32-a},g:function(a){var b,c,d,e,f,g,h=a.slice(0),i=this.c;c=i[0];d=i[1];e=i[2];f=i[3];g=i[4];for(a=0;a<=79;a++){if(a>=
16)h[a]=this.z(1,h[a-3]^h[a-8]^h[a-14]^h[a-16]);b=this.z(5,c)+this.X(a,d,e,f)+g+h[a]+this.d[Math.floor(a/20)]|0;g=f;f=e;e=this.z(30,d);d=c;c=b}i[0]=i[0]+c|0;i[1]=i[1]+d|0;i[2]=i[2]+e|0;i[3]=i[3]+f|0;i[4]=i[4]+g|0}};sjcl.bn=function(a){this.initWith(a)};
sjcl.bn.prototype={radix:24,maxMul:8,f:sjcl.bn,copy:function(){return new this.f(this)},initWith:function(a){var b=0,c;switch(typeof a){case "object":this.limbs=a.limbs.slice(0);break;case "number":this.limbs=[a];this.normalize();break;case "string":a=a.replace(/^0x/,"");this.limbs=[];c=this.radix/4;for(b=0;b<a.length;b+=c)this.limbs.push(parseInt(a.substring(Math.max(a.length-b-c,0),a.length-b),16));break;default:this.limbs=[0]}return this},equals:function(a){if(typeof a==="number")a=new this.f(a);
var b=0,c;this.fullReduce();a.fullReduce();for(c=0;c<this.limbs.length||c<a.limbs.length;c++)b|=this.getLimb(c)^a.getLimb(c);return b===0},getLimb:function(a){return a>=this.limbs.length?0:this.limbs[a]},greaterEquals:function(a){if(typeof a==="number")a=new this.f(a);var b=0,c=0,d,e,f;for(d=Math.max(this.limbs.length,a.limbs.length)-1;d>=0;d--){e=this.getLimb(d);f=a.getLimb(d);c|=f-e&~b;b|=e-f&~c}return(c|~b)>>>31},toString:function(){this.fullReduce();var a="",b,c,d=this.limbs;for(b=0;b<this.limbs.length;b++){for(c=
d[b].toString(16);b<this.limbs.length-1&&c.length<6;)c="0"+c;a=c+a}return"0x"+a},addM:function(a){if(typeof a!=="object")a=new this.f(a);var b=this.limbs,c=a.limbs;for(a=b.length;a<c.length;a++)b[a]=0;for(a=0;a<c.length;a++)b[a]+=c[a];return this},doubleM:function(){var a,b=0,c,d=this.radix,e=this.radixMask,f=this.limbs;for(a=0;a<f.length;a++){c=f[a];c=c+c+b;f[a]=c&e;b=c>>d}b&&f.push(b);return this},halveM:function(){var a,b=0,c,d=this.radix,e=this.limbs;for(a=e.length-1;a>=0;a--){c=e[a];e[a]=c+b>>
1;b=(c&1)<<d}e[e.length-1]||e.pop();return this},subM:function(a){if(typeof a!=="object")a=new this.f(a);var b=this.limbs,c=a.limbs;for(a=b.length;a<c.length;a++)b[a]=0;for(a=0;a<c.length;a++)b[a]-=c[a];return this},mod:function(a){a=(new sjcl.bn(a)).normalize();for(var b=(new sjcl.bn(this)).normalize(),c=0;b.greaterEquals(a);c++)a.doubleM();for(;c>0;c--){a.halveM();b.greaterEquals(a)&&b.subM(a).normalize()}return b.trim()},inverseMod:function(a){var b=new sjcl.bn(1),c=new sjcl.bn(0),d=new sjcl.bn(this),
e=new sjcl.bn(a),f,g=1;if(!(a.limbs[0]&1))throw new sjcl.exception.invalid("inverseMod: p must be odd");do{if(d.limbs[0]&1){if(!d.greaterEquals(e)){f=d;d=e;e=f;f=b;b=c;c=f}d.subM(e);d.normalize();b.greaterEquals(c)||b.addM(a);b.subM(c)}d.halveM();b.limbs[0]&1&&b.addM(a);b.normalize();b.halveM();for(f=g=0;f<d.limbs.length;f++)g|=d.limbs[f]}while(g);if(!e.equals(1))throw new sjcl.exception.invalid("inverseMod: p and x must be relatively prime");return c},add:function(a){return this.copy().addM(a)},
sub:function(a){return this.copy().subM(a)},mul:function(a){if(typeof a==="number")a=new this.f(a);var b,c=this.limbs,d=a.limbs,e=c.length,f=d.length,g=new this.f,h=g.limbs,i,k=this.maxMul;for(b=0;b<this.limbs.length+a.limbs.length+1;b++)h[b]=0;for(b=0;b<e;b++){i=c[b];for(a=0;a<f;a++)h[b+a]+=i*d[a];if(!--k){k=this.maxMul;g.cnormalize()}}return g.cnormalize().reduce()},square:function(){return this.mul(this)},power:function(a){if(typeof a==="number")a=[a];else if(a.limbs!==undefined)a=a.normalize().limbs;
var b,c,d=new this.f(1),e=this;for(b=0;b<a.length;b++)for(c=0;c<this.radix;c++){if(a[b]&1<<c)d=d.mul(e);e=e.square()}return d},mulmod:function(a,b){return this.mod(b).mul(a.mod(b)).mod(b)},powermod:function(a,b){var c=new sjcl.bn(1),d=new sjcl.bn(this);for(a=new sjcl.bn(a);;){if(a.limbs[0]&1)c=c.mulmod(d,b);a.halveM();if(a.equals(0))break;d=d.mulmod(d,b)}return c.normalize().reduce()},trim:function(){var a=this.limbs,b;do b=a.pop();while(a.length&&b===0);a.push(b);return this},reduce:function(){return this},
fullReduce:function(){return this.normalize()},normalize:function(){var a=0,b,c=this.ipv,d,e=this.limbs,f=e.length,g=this.radixMask;for(b=0;b<f||a!==0&&a!==-1;b++){a=(e[b]||0)+a;d=e[b]=a&g;a=(a-d)*c}if(a===-1)e[b-1]-=this.placeVal;return this},cnormalize:function(){var a=0,b,c=this.ipv,d,e=this.limbs,f=e.length,g=this.radixMask;for(b=0;b<f-1;b++){a=e[b]+a;d=e[b]=a&g;a=(a-d)*c}e[b]+=a;return this},toBits:function(a){this.fullReduce();a=a||this.exponent||this.limbs.length*this.radix;var b=Math.floor((a-
1)/24),c=sjcl.bitArray;a=[c.partial((a+7&-8)%this.radix||this.radix,this.getLimb(b))];for(b--;b>=0;b--)a=c.concat(a,[c.partial(this.radix,this.getLimb(b))]);return a},bitLength:function(){this.fullReduce();for(var a=this.radix*(this.limbs.length-1),b=this.limbs[this.limbs.length-1];b;b>>=1)a++;return a+7&-8}};
sjcl.bn.fromBits=function(a){var b=new this,c=[],d=sjcl.bitArray,e=this.prototype,f=Math.min(this.bitLength||0x100000000,d.bitLength(a)),g=f%e.radix||e.radix;for(c[0]=d.extract(a,0,g);g<f;g+=e.radix)c.unshift(d.extract(a,g,e.radix));b.limbs=c;return b};sjcl.bn.prototype.ipv=1/(sjcl.bn.prototype.placeVal=Math.pow(2,sjcl.bn.prototype.radix));sjcl.bn.prototype.radixMask=(1<<sjcl.bn.prototype.radix)-1;
sjcl.bn.pseudoMersennePrime=function(a,b){function c(g){this.initWith(g)}var d=c.prototype=new sjcl.bn,e,f;e=d.modOffset=Math.ceil(f=a/d.radix);d.exponent=a;d.offset=[];d.factor=[];d.minOffset=e;d.fullMask=0;d.fullOffset=[];d.fullFactor=[];d.modulus=c.modulus=new sjcl.bn(Math.pow(2,a));d.fullMask=0|-Math.pow(2,a%d.radix);for(e=0;e<b.length;e++){d.offset[e]=Math.floor(b[e][0]/d.radix-f);d.fullOffset[e]=Math.ceil(b[e][0]/d.radix-f);d.factor[e]=b[e][1]*Math.pow(0.5,a-b[e][0]+d.offset[e]*d.radix);d.fullFactor[e]=
b[e][1]*Math.pow(0.5,a-b[e][0]+d.fullOffset[e]*d.radix);d.modulus.addM(new sjcl.bn(Math.pow(2,b[e][0])*b[e][1]));d.minOffset=Math.min(d.minOffset,-d.offset[e])}d.f=c;d.modulus.cnormalize();d.reduce=function(){var g,h,i,k=this.modOffset,j=this.limbs,l=this.offset,m=this.offset.length,n=this.factor,o;for(g=this.minOffset;j.length>k;){i=j.pop();o=j.length;for(h=0;h<m;h++)j[o+l[h]]-=n[h]*i;g--;if(!g){j.push(0);this.cnormalize();g=this.minOffset}}this.cnormalize();return this};d.U=d.fullMask===-1?d.reduce:
function(){var g=this.limbs,h=g.length-1,i,k;this.reduce();if(h===this.modOffset-1){k=g[h]&this.fullMask;g[h]-=k;for(i=0;i<this.fullOffset.length;i++)g[h+this.fullOffset[i]]-=this.fullFactor[i]*k;this.normalize()}};d.fullReduce=function(){var g,h;this.U();this.addM(this.modulus);this.addM(this.modulus);this.normalize();this.U();for(h=this.limbs.length;h<this.modOffset;h++)this.limbs[h]=0;g=this.greaterEquals(this.modulus);for(h=0;h<this.limbs.length;h++)this.limbs[h]-=this.modulus.limbs[h]*g;this.cnormalize();
return this};d.inverse=function(){return this.power(this.modulus.sub(2))};c.fromBits=sjcl.bn.fromBits;return c};
sjcl.bn.prime={p127:sjcl.bn.pseudoMersennePrime(127,[[0,-1]]),p25519:sjcl.bn.pseudoMersennePrime(255,[[0,-19]]),p192:sjcl.bn.pseudoMersennePrime(192,[[0,-1],[64,-1]]),p224:sjcl.bn.pseudoMersennePrime(224,[[0,1],[96,-1]]),p256:sjcl.bn.pseudoMersennePrime(0x100,[[0,-1],[96,1],[192,1],[224,-1]]),p384:sjcl.bn.pseudoMersennePrime(384,[[0,-1],[32,1],[96,-1],[128,-1]]),p521:sjcl.bn.pseudoMersennePrime(521,[[0,-1]])};
sjcl.bn.random=function(a,b){if(typeof a!=="object")a=new sjcl.bn(a);for(var c,d,e=a.limbs.length,f=a.limbs[e-1]+1,g=new sjcl.bn;;){do{c=sjcl.random.randomWords(e,b);if(c[e-1]<0)c[e-1]+=0x100000000}while(Math.floor(c[e-1]/f)===Math.floor(0x100000000/f));c[e-1]%=f;for(d=0;d<e-1;d++)c[d]&=a.radixMask;g.limbs=c;if(!g.greaterEquals(a))return g}};sjcl.hash.md5=function(a){this.A[0]||this.r();if(a){this.c=a.c.slice(0);this.b=a.b.slice(0);this.a=a.a}else this.reset()};sjcl.hash.md5.hash=function(a){return(new sjcl.hash.md5).update(a).finalize()};
sjcl.hash.md5.prototype={blockSize:512,reset:function(){this.c=this.l.slice(0);this.b=[];this.a=0;return this},update:function(a){if(typeof a==="string")a=sjcl.codec.utf8String.toBits(a);var b,c=this.b=sjcl.bitArray.concat(this.b,a);b=this.a;a=this.a=b+sjcl.bitArray.bitLength(a);for(b=this.blockSize+b&-this.blockSize;b<=a;b+=this.blockSize)this.g(c.splice(0,16),true);return this},finalize:function(){var a,b=this.b,c=this.c;b=sjcl.bitArray.concat(b,[sjcl.bitArray.partial(1,1)]);for(a=b.length+2;a&
15;a++)b.push(0);b.push(this.a|0);for(b.push(this.a/0x100000000|0);b.length;)this.g(b.splice(0,16),b.length);this.reset();this.I(c,4);return c},l:[1732584193,4023233417,2562383102,271733878],I:function(a,b){var c,d;for(c=0;c<b;c++){d=a[c];a[c]=d>>>24|d>>8&0xff00|(d&0xff00)<<8|(d&255)<<24}},A:[],r:function(){var a;for(a=0;a<64;a++)this.A[a]=0x100000000*Math.abs(Math.sin(a+1))|0},g:function(a,b){var c,d,e,f=a.slice(0),g=this.c,h=this.A;a=g[0];c=g[1];d=g[2];e=g[3];this.I(f,b?16:14);for(b=0;b<64;b++){var i,
k,j;if(b<32)if(b<16){i=c&d|~c&e;k=b;j=[7,12,17,22]}else{i=e&c|~e&d;k=(5*b+1)%16;j=[5,9,14,20]}else if(b<48){i=c^d^e;k=(3*b+5)%16;j=[4,11,16,23]}else{i=d^(c|~e);k=7*b%16;j=[6,10,15,21]}i=a+i+f[k]+h[b];a=e;e=d;d=c;c=(i<<j[b%4]|i>>>32-j[b%4])+c|0}g[0]+=a;g[1]+=c;g[2]+=d;g[3]+=e}};
sjcl.misc.hmac_sha1=function(a,b){this.p=b=b||sjcl.hash.sha1;var c=[[],[]],d=b.prototype.blockSize/32;this.e=[new b,new b];if(a.length>d)a=b.hash(a);for(b=0;b<d;b++){c[0][b]=a[b]^909522486;c[1][b]=a[b]^1549556828}this.e[0].update(c[0]);this.e[1].update(c[1])};sjcl.misc.hmac_sha1.prototype.encrypt=sjcl.misc.hmac_sha1.prototype.mac=function(a,b){a=(new this.p(this.e[0])).update(a,b).finalize();return(new this.p(this.e[1])).update(a).finalize()};
sjcl.misc.pbkdf2=function(a,b,c,d,e){c=c||1E3;if(d<0||c<0)throw sjcl.exception.invalid("invalid params to pbkdf2");if(typeof a==="string")a=sjcl.codec.utf8String.toBits(a);e=e||sjcl.misc.hmac;a=new e(a);var f,g,h,i,k=[],j=sjcl.bitArray;for(i=1;32*k.length<(d||1);i++){e=f=a.encrypt(j.concat(b,[i]));for(g=1;g<c;g++){f=a.encrypt(f);for(h=0;h<f.length;h++)e[h]^=f[h]}k=k.concat(e)}if(d)k=j.clamp(k,d);return k};
sjcl.random={randomWords:function(a,b){var c=[];b=this.isReady(b);var d;if(b===0)throw new sjcl.exception.notReady("generator isn't seeded");else b&2&&this.$(!(b&1));for(b=0;b<a;b+=4){(b+1)%0x10000===0&&this.R();d=this.F();c.push(d[0],d[1],d[2],d[3])}this.R();return c.slice(0,a)},setDefaultParanoia:function(a){this.D=a},addEntropy:function(a,b,c){c=c||"user";var d,e,f=(new Date).valueOf(),g=this.w[c],h=this.isReady();d=this.L[c];if(d===undefined)d=this.L[c]=this.W++;if(g===undefined)g=this.w[c]=0;this.w[c]=
(this.w[c]+1)%this.h.length;switch(typeof a){case "number":break;case "object":if(b===undefined)for(c=b=0;c<a.length;c++)for(e=a[c];e>0;){b++;e>>>=1}this.h[g].update([d,this.P++,2,b,f,a.length].concat(a));break;case "string":if(b===undefined)b=a.length;this.h[g].update([d,this.P++,3,b,f,a.length]);this.h[g].update(a);break;default:throw new sjcl.exception.bug("random: addEntropy only supports number, array or string");}this.q[g]+=b;this.m+=b;if(h===0){this.isReady()!==0&&this.Q("seeded",Math.max(this.n,
this.m));this.Q("progress",this.getProgress())}},isReady:function(a){a=this.J[a!==undefined?a:this.D];return this.n&&this.n>=a?this.q[0]>80&&(new Date).valueOf()>this.S?3:1:this.m>=a?2:0},getProgress:function(a){a=this.J[a?a:this.D];return this.n>=a?1["0"]:this.m>a?1["0"]:this.m/a},startCollectors:function(){if(!this.s){if(window.addEventListener){window.addEventListener("load",this.t,false);window.addEventListener("mousemove",this.u,false)}else if(document.attachEvent){document.attachEvent("onload",
this.t);document.attachEvent("onmousemove",this.u)}else throw new sjcl.exception.bug("can't attach event");this.s=true}},stopCollectors:function(){if(this.s){if(window.removeEventListener){window.removeEventListener("load",this.t,false);window.removeEventListener("mousemove",this.u,false)}else if(window.detachEvent){window.detachEvent("onload",this.t);window.detachEvent("onmousemove",this.u)}this.s=false}},addEventListener:function(a,b){this.B[a][this.V++]=b},removeEventListener:function(a,b){var c;
a=this.B[a];var d=[];for(c in a)a.hasOwnProperty(c)&&a[c]===b&&d.push(c);for(b=0;b<d.length;b++){c=d[b];delete a[c]}},h:[new sjcl.hash.sha256],q:[0],G:0,w:{},P:0,L:{},W:0,n:0,m:0,S:0,d:[0,0,0,0,0,0,0,0],j:[0,0,0,0],C:undefined,D:6,s:false,B:{progress:{},seeded:{}},V:0,J:[0,48,64,96,128,192,0x100,384,512,768,1024],F:function(){for(var a=0;a<4;a++){this.j[a]=this.j[a]+1|0;if(this.j[a])break}return this.C.encrypt(this.j)},R:function(){this.d=this.F().concat(this.F());this.C=new sjcl.cipher.aes(this.d)},
Z:function(a){this.d=sjcl.hash.sha256.hash(this.d.concat(a));this.C=new sjcl.cipher.aes(this.d);for(a=0;a<4;a++){this.j[a]=this.j[a]+1|0;if(this.j[a])break}},$:function(a){var b=[],c=0,d;this.S=b[0]=(new Date).valueOf()+3E4;for(d=0;d<16;d++)b.push(Math.random()*0x100000000|0);for(d=0;d<this.h.length;d++){b=b.concat(this.h[d].finalize());c+=this.q[d];this.q[d]=0;if(!a&&this.G&1<<d)break}if(this.G>=1<<this.h.length){this.h.push(new sjcl.hash.sha256);this.q.push(0)}this.m-=c;if(c>this.n)this.n=c;this.G++;
this.Z(b)},u:function(a){sjcl.random.addEntropy([a.x||a.clientX||a.offsetX,a.y||a.clientY||a.offsetY],2,"mouse")},t:function(){sjcl.random.addEntropy(new Date,2,"loadtime")},Q:function(a,b){var c;a=sjcl.random.B[a];var d=[];for(c in a)a.hasOwnProperty(c)&&d.push(a[c]);for(c=0;c<d.length;c++)d[c](b)}};try{var s=new Uint32Array(32);crypto.getRandomValues(s);sjcl.random.addEntropy(s,1024,"crypto['getRandomValues']")}catch(t){}
sjcl.json={defaults:{v:1,iter:1E3,ks:128,ts:64,mode:"ccm",adata:"",cipher:"aes"},encrypt:function(a,b,c,d){c=c||{};d=d||{};var e=sjcl.json,f=e.i({iv:sjcl.random.randomWords(4,0)},e.defaults);e.i(f,c);if(typeof f.salt==="string")f.salt=sjcl.codec.base64.toBits(f.salt);if(typeof f.iv==="string")f.iv=sjcl.codec.base64.toBits(f.iv);if(!sjcl.mode[f.mode]||!sjcl.cipher[f.cipher]||typeof a==="string"&&f.iter<=100||f.ts!==64&&f.ts!==96&&f.ts!==128||f.ks!==128&&f.ks!==192&&f.ks!==0x100||f.iv.length<2||f.iv.length>
4)throw new sjcl.exception.invalid("json encrypt: invalid parameters: "+JSON.stringify(f));if(typeof a==="string"){c=sjcl.misc.cachedPbkdf2(a,f);a=c.key.slice(0,f.ks/32);f.salt=c.salt}if(typeof b==="string")b=sjcl.codec.utf8String.toBits(b);c=new sjcl.cipher[f.cipher](a);e.i(d,f);d.key=a;f.ct=sjcl.mode[f.mode].encrypt(c,b,f.iv,f.adata,f.ts);return e.encode(e.aa(f,e.defaults))},decrypt:function(a,b,c,d){c=c||{};d=d||{};var e=sjcl.json;b=e.i(e.i(e.i({},e.defaults),e.decode(b)),c,true);if(typeof b.salt===
"string")b.salt=sjcl.codec.base64.toBits(b.salt);if(typeof b.iv==="string")b.iv=sjcl.codec.base64.toBits(b.iv);if(!sjcl.mode[b.mode]||!sjcl.cipher[b.cipher]||typeof a==="string"&&b.iter<=100||b.ts!==64&&b.ts!==96&&b.ts!==128||b.ks!==128&&b.ks!==192&&b.ks!==0x100||!b.iv||b.iv.length<2||b.iv.length>4)throw new sjcl.exception.invalid("json decrypt: invalid parameters");if(typeof a==="string"){c=sjcl.misc.cachedPbkdf2(a,b);a=c.key.slice(0,b.ks/32);b.salt=c.salt}c=new sjcl.cipher[b.cipher](a);c=sjcl.mode[b.mode].decrypt(c,
b.ct,b.iv,b.adata,b.ts);e.i(d,b);d.key=a;return sjcl.codec.utf8String.fromBits(c)},encode:function(a){var b,c="{",d="";for(b in a)if(a.hasOwnProperty(b)){if(!b.match(/^[a-z0-9]+$/i))throw new sjcl.exception.invalid("json encode: invalid property name");c+=d+b+":";d=",";switch(typeof a[b]){case "number":case "boolean":c+=a[b];break;case "string":c+='"'+escape(a[b])+'"';break;case "object":c+='"'+sjcl.codec.base64.fromBits(a[b],1)+'"';break;default:throw new sjcl.exception.bug("json encode: unsupported type");
}}return c+"}"},decode:function(a){a=a.replace(/\s/g,"");if(!a.match(/^\{.*\}$/))throw new sjcl.exception.invalid("json decode: this isn't json: "+a);a=a.replace(/^\{|\}$/g,"").split(/,/);var b={},c,d;for(c=0;c<a.length;c++){if(!(d=a[c].match(/^([a-z][a-z0-9]*):(?:(\d+)|"([a-z0-9+\/%*_.@=\-]*)")$/i)))throw new sjcl.exception.invalid("json decode: this isn't json!");b[d[1]]=d[2]?parseInt(d[2],10):d[1].match(/^(ct|salt|iv)$/)?sjcl.codec.base64.toBits(d[3]):unescape(d[3])}return b},i:function(a,b,c){if(a===
undefined)a={};if(b===undefined)return a;var d;for(d in b)if(b.hasOwnProperty(d)){if(c&&a[d]!==undefined&&a[d]!==b[d])throw new sjcl.exception.invalid("required parameter overridden");a[d]=b[d]}return a},aa:function(a,b){var c={},d;for(d in a)if(a.hasOwnProperty(d)&&a[d]!==b[d])c[d]=a[d];return c},ba:function(a,b){var c={},d;for(d=0;d<b.length;d++)if(a[b[d]]!==undefined)c[b[d]]=a[b[d]];return c}};sjcl.encrypt=sjcl.json.encrypt;sjcl.decrypt=sjcl.json.decrypt;sjcl.misc.Y={};
sjcl.misc.cachedPbkdf2=function(a,b){var c=sjcl.misc.Y,d;b=b||{};d=b.iter||1E3;c=c[a]=c[a]||{};d=c[d]=c[d]||{firstSalt:b.salt&&b.salt.length?b.salt.slice(0):sjcl.random.randomWords(2,0)};c=b.salt===undefined?d.firstSalt:b.salt;d[c]=d[c]||sjcl.misc.pbkdf2(a,c,b.iter);return{key:d[c].slice(0),salt:c.slice(0)}};
sjcl.mode.cbc={name:"cbc",encrypt:function(a,b,c,d){if(d&&d.length)throw new sjcl.exception.invalid("cbc can't authenticate data");if(sjcl.bitArray.bitLength(c)!==128)throw new sjcl.exception.invalid("cbc iv must be 128 bits");var e=sjcl.bitArray,f=e.k,g=e.bitLength(b),h=0,i=[];if(g&7)throw new sjcl.exception.invalid("pkcs#5 padding only works for multiples of a byte");for(d=0;h+128<=g;d+=4,h+=128){c=a.encrypt(f(c,b.slice(d,d+4)));i.splice(d,0,c[0],c[1],c[2],c[3])}g=(16-(g>>3&15))*0x1010101;c=a.encrypt(f(c,
e.concat(b,[g,g,g,g]).slice(d,d+4)));i.splice(d,0,c[0],c[1],c[2],c[3]);return i},decrypt:function(a,b,c,d){if(d&&d.length)throw new sjcl.exception.invalid("cbc can't authenticate data");if(sjcl.bitArray.bitLength(c)!==128)throw new sjcl.exception.invalid("cbc iv must be 128 bits");if(sjcl.bitArray.bitLength(b)&127||!b.length)throw new sjcl.exception.corrupt("cbc ciphertext must be a positive multiple of the block size");var e=sjcl.bitArray,f=e.k,g,h=[];for(d=0;d<b.length;d+=4){g=b.slice(d,d+4);c=
f(c,a.decrypt(g));h.splice(d,0,c[0],c[1],c[2],c[3]);c=g}g=h[d-1]&255;if(g==0||g>16)throw new sjcl.exception.corrupt("pkcs#5 padding corrupt");c=g*0x1010101;if(!e.equal(e.bitSlice([c,c,c,c],0,g*8),e.bitSlice(h,h.length*32-g*8,h.length*32)))throw new sjcl.exception.corrupt("pkcs#5 padding corrupt");return e.bitSlice(h,0,h.length*32-g*8)}};
var g=!0,i=null,j=!1,Cc=require("chrome").Cc,Ci=require("chrome").Ci,aa=Cc["@mozilla.org/storage/service;1"].getService(Ci.mozIStorageService);function WebDatabase(b,c,a){this.description=a;c=Cc["@mozilla.org/file/directory_service;1"].getService(Ci.nsIProperties).get("ProfD",Ci.nsIFile);c.append("..");c.append(b+".sqlite");(this.n=aa.openDatabase(c))||console&&console.error("[SQLITE] Couldn't connect to database.")}
WebDatabase.prototype.readTransaction=WebDatabase.prototype.transaction=function(b,c,a){c=new l(this.n,c,a);try{b(c)}catch(d){console&&console.error("[SQLITE] Transaction failed: "+d)}};function l(b,c,a){this.n=b;this.error=i;this.h=c;this.u=a;this.S=[];this.b=i}l.prototype.queueStatement=function(b,c,a,d){this.S.push({ub:b,mb:c,u:a,h:d})};
l.prototype.processNextStatementInQueue=function(){if(this.error)this.h&&this.h(this.error);else if(0==this.S.length)this.u&&this.u(this);else{this.b=this.S.shift();try{this.executeSqlStatement(this.b.ub,this.b.mb,this.b.u,this.b.h)}catch(b){this.b.h&&this.b.h()}}};
l.prototype.executeSqlStatement=function(b,c,a,d){var e=this.n.createStatement(b);if(c)for(b=0;b<c.length;++b)e.bindByIndex(b,c[b]);var f=this,h={rows:{item:function(a){return this.V[a]},V:[],length:0}};e.executeAsync({handleResult:function(a){f.processResults(a,e,h)},handleError:function(a){console.error("[SQLITE] handleError: "+a.message);d&&d(f,a);f.error=a;f.b=i;f.processNextStatementInQueue()},handleCompletion:function(b){b!=Ci.mozIStorageStatementCallback.REASON_FINISHED&&console&&console.error("[SQLITE] Query canceled or aborted!");
a&&a(f,h);f.b=i;f.processNextStatementInQueue()}})};l.prototype.executeSql=function(b,c,a,d){this.queueStatement(b,c,a,d);this.b==i&&this.processNextStatementInQueue()};l.prototype.processResults=function(b,c,a){try{for(var d=b.getNextRow();d;){for(var e={},f=0;f<d.numEntries;++f)e[c.getColumnName(f)]=d.getResultByIndex(f);a.rows.V.push(e);a.rows.length+=1;d=b.getNextRow()}}catch(h){n(h)}};var o=require("timer");setTimeout=o.setTimeout;clearTimeout=o.clearTimeout;setInterval=o.setInterval;
clearInterval=o.clearInterval;var hiddenFrames=require("hidden-frame"),WebSocket=i;hiddenFrames.add(hiddenFrames.HiddenFrame({onReady:function(){this.element.contentWindow.location.href=require("self").data.url("ui/popup.html");var b=this;this.element.addEventListener("DOMContentLoaded",function(){WebSocket=b.element.contentWindow.MozWebSocket||b.element.contentWindow.WebSocket},g,g)}}));
var ba={Aa:function(b){for(var c=[0,1996959894,3993919788,2567524794,124634137,1886057615,3915621685,2657392035,249268274,2044508324,3772115230,2547177864,162941995,2125561021,3887607047,2428444049,498536548,1789927666,4089016648,2227061214,450548861,1843258603,4107580753,2211677639,325883990,1684777152,4251122042,2321926636,335633487,1661365465,4195302755,2366115317,997073096,1281953886,3579855332,2724688242,1006888145,1258607687,3524101629,2768942443,901097722,1119000684,3686517206,2898065728,853044451,
1172266101,3705015759,2882616665,651767980,1373503546,3369554304,3218104598,565507253,1454621731,3485111705,3099436303,671266974,1594198024,3322730930,2970347812,795835527,1483230225,3244367275,3060149565,1994146192,31158534,2563907772,4023717930,1907459465,112637215,2680153253,3904427059,2013776290,251722036,2517215374,3775830040,2137656763,141376813,2439277719,3865271297,1802195444,476864866,2238001368,4066508878,1812370925,453092731,2181625025,4111451223,1706088902,314042704,2344532202,4240017532,
1658658271,366619977,2362670323,4224994405,1303535960,984961486,2747007092,3569037538,1256170817,1037604311,2765210733,3554079995,1131014506,879679996,2909243462,3663771856,1141124467,855842277,2852801631,3708648649,1342533948,654459306,3188396048,3373015174,1466479909,544179635,3110523913,3462522015,1591671054,702138776,2966460450,3352799412,1504918807,783551873,3082640443,3233442989,3988292384,2596254646,62317068,1957810842,3939845945,2647816111,81470997,1943803523,3814918930,2489596804,225274430,
2053790376,3826175755,2466906013,167816743,2097651377,4027552580,2265490386,503444072,1762050814,4150417245,2154129355,426522225,1852507879,4275313526,2312317920,282753626,1742555852,4189708143,2394877945,397917763,1622183637,3604390888,2714866558,953729732,1340076626,3518719985,2797360999,1068828381,1219638859,3624741850,2936675148,906185462,1090812512,3747672003,2825379669,829329135,1181335161,3412177804,3160834842,628085408,1382605366,3423369109,3138078467,570562233,1426400815,3317316542,2998733608,
733239954,1555261956,3268935591,3050360625,752459403,1541320221,2607071920,3965973030,1969922972,40735498,2617837225,3943577151,1913087877,83908371,2512341634,3803740692,2075208622,213261112,2463272603,3855990285,2094854071,198958881,2262029012,4057260610,1759359992,534414190,2176718541,4139329115,1873836001,414664567,2282248934,4279200368,1711684554,285281116,2405801727,4167216745,1634467795,376229701,2685067896,3608007406,1308918612,956543938,2808555105,3495958263,1231636301,1047427035,2932959818,
3654703836,1088359270,936918E3,2847714899,3736837829,1202900863,817233897,3183342108,3401237130,1404277552,615818150,3134207493,3453421203,1423857449,601450431,3009837614,3294710456,1567103746,711928724,3020668471,3272380065,1510334235,755167117],a=-1,d=0;d<b.length;d++)a=a>>>8^c[(a^b[d])&255]&4294967295;a=~a;0>a&&(a+=4294967296);return 0==a?1:a}},ca="UnlockPasswordAccepted",da="UnlockPasswordRejected",ea="UnlockDataNotAvailable",fa="UnlockAgentNotConnected",ha="UnlockAgentIsSyncing",ia="UnlockPasswordUnknownError";
function ja(){var b=/Windows/;return"object"==typeof navigator?navigator.userAgent.match(b):j}function u(b){var c="";return c="object"==typeof safari?safari.extension.baseURI+b:"object"==typeof chrome?chrome.extension.getURL(b):require("self").data.url(b)}function n(b){console.error("Exception caught:\n  name: %s\n  type: %s\n  message: %s\n  stack: %s\n  %s:%s",b.name,b.type,b.message,b.stack,b.sourceURL,b.line);console.error("Exception: "+JSON.stringify(b))}
function ka(b){return(b=b.match(/(.*?:\/\/(.[^/]+))/))?b[1]:""}var la=150;function ma(b){for(var c=[],a=0,d=b.length;a<d;a++)c.push(la^b.charCodeAt(a));return c}function w(b){if(!b)return"";for(var c="",a=0,d=b.length;a<d;a++)c+=String.fromCharCode(la^b[a]);return c}
var na={s:function(){function b(){return(65536*(1+Math.random())|0).toString(16).substring(1).toUpperCase()}return[b(),b(),b(),b(),b(),b(),b(),b()].join("")}},y=function(){function b(b,c){var d=sjcl.random.randomWords(2,0),q=h(b,d),d=sjcl.bitArray.concat(m,d),q=e(q.key,q.iv,c),q=sjcl.bitArray.concat(d,q);return a(q)}function c(a,b){var c=d(b),e=sjcl.bitArray.bitSlice(c,0,64),A=r;sjcl.bitArray.equal(e,m)&&(A=sjcl.bitArray.bitSlice(c,64,128),c=sjcl.bitArray.bitSlice(c,128));e=h(a,A);return f(e.key,
e.iv,c)}function a(a){return sjcl.codec.base64.fromBits(a)}function d(a){return sjcl.codec.base64.toBits(a.replace("\x00",""))}function e(a,b,c){try{var d=new sjcl.cipher.aes(a);return sjcl.mode.cbc.encrypt(d,c,b,i)}catch(e){console.error("[CRYPTO] Failed to encrypt: "+e.message)}}function f(a,b,c){try{var d=new sjcl.cipher.aes(a);return sjcl.mode.cbc.decrypt(d,c,b,i)}catch(e){console.error("[CRYPTO] Failed to decrypt: "+e.message)}}function h(a,b){b||(b=r);var c=i,c=0<b.length?sjcl.bitArray.concat(a,
b):a,d=sjcl.hash.md5.hash(c),e=sjcl.hash.md5.hash(sjcl.bitArray.concat(d,c)),c=sjcl.hash.md5.hash(sjcl.bitArray.concat(e,c));return{key:sjcl.bitArray.concat(d,e),iv:c}}var m=sjcl.codec.bytes.toBits([83,97,108,116,101,100,95,95]),r=sjcl.codec.bytes.toBits([0,0,0,0,0,0,0,0]),t=sjcl.codec.utf8String.toBits("dpGHuBcGmKaQfVEvFmd1M6eFpmFuNL");return{Yb:function(a){return!a?i:b(t,sjcl.codec.utf8String.toBits(a))},Qa:function(a){if(!a)return i;a=c(t,a);return sjcl.codec.utf8String.fromBits(a)},openSSLKey:h,
Fa:d,Ha:a,M:c,N:b,Ba:function(a,b,c){var c=d(c),e=sjcl.bitArray.bitSlice(c,0,64),A=r;sjcl.bitArray.equal(e,m)&&(A=sjcl.bitArray.bitSlice(c,64,128),c=sjcl.bitArray.bitSlice(c,128));b=sjcl.misc.pbkdf2(a,A,b,384,sjcl.misc.hmac_sha1);a=sjcl.bitArray.bitSlice(b,0,256);b=sjcl.bitArray.bitSlice(b,256);return f(a,b,c)},Pa:f,Sa:e}}();function oa(b){this.I=b}
oa.prototype={Eb:function(){return this.I.secureContents||{}},da:function(){return this.Eb().fields},aa:function(b){var c=this.da();if(!c)return i;for(var a=0;a<c.length;++a){var d=c[a];if(d.designation===b)return d}return i},setTitle:function(b){this.I.overview.title=b},location:function(){return this.I.overview.location},Rb:function(){var b=this.aa("username");return b?b.value:""},O:function(){var b=this.aa("password");return b?b.value:""},Ta:function(b){var c=this.da();if(!c)return[];for(var a=
[],d=0;d<c.length;++d){var e=c[d].type;e&&0<=b.indexOf(e)&&a.push(c[d])}return a},nb:function(){return this.Ta(["P"])}};
var B=function(){function b(b){b||(b=[]);try{h=b;var c=sjcl.encrypt("S7BQMkwBJRsrQVb}Zjz9BJS+xuOIhaad",b.join("\n"),f);a("doNotAutosaveOn",c)}catch(d){console.error("[SETTINGS] Failed to setDoNotAutosaveOnDomains: "+d.message)}}function c(){if(h)return h;var a=e("doNotAutosaveOn",i);if(!a)return h=[];try{var b=sjcl.decrypt("S7BQMkwBJRsrQVb}Zjz9BJS+xuOIhaad",a,f);return h=b?b.split("\n"):[]}catch(c){return console.error("[SETTINGS] Failed to decrypt"),h=[]}}function a(a,b){"object"==typeof chrome?
localStorage[a]=b:"object"==typeof safari?safari.extension.settings[a]=b:"object"==typeof sa?sa[a]=b:console.log("[SETTINGS] Failed to setValue")}function d(a,b){var c=e(a);return"number"==typeof c?c:c?parseInt(c,10):b}function e(a,b){var c=i;"object"==typeof chrome?c=localStorage[a]:"object"==typeof safari?c=safari.extension.settings[a]:"object"==typeof sa?c=sa[a]:console.log("[SETTINGS] Failed to getValue");return c?c:b}var f={v:1,iter:105,ks:128,ts:64,mode:"cbc",cipher:"aes"},h=i;return{Wb:e,getString:e,
Vb:d,setValue:a,getAll:function(){var a={};a.autosave=e("autosave")||"Y";a.autosubmit=e("autosubmit")||"Y";return a},ta:function(b){b.autosave&&a("autosave",b.autosave);b.autosubmit&&a("autosubmit",b.autosubmit)},U:function(){return"N"!=e("universalUnlock")},wa:function(a){var b={};b.autosubmit="Y"==e("autosubmit","Y");if("N"!=e("autosave","Y"))a:{for(var a=z.A(a),d=z.ha(a),k=c(),p=0;p<k.length;++p){var v=k[p];if(v===a||v===d){a=j;break a}}a=g}else a=j;b.autosave=a;return b},d:function(){var a={};
a.autosave="N"!=e("autosave");a.autosubmit="N"!=e("autosubmit");a.universalUnlock="N"!=e("universalUnlock");a.concealPasswords="N"!=e("concealPasswords");a.tabUsedForGoAndFill=e("tabUsedForGoAndFill")||"NewTab";a.doNotAutosaveOnDomains=c().join("\n");a.useAnimation="N"!=e("useAnimation");a.includeUsernameInAutosave="N"!=e("includeUsernameInAutosave");return a},Gb:function(c){a("autosave",c.autosave?"Y":"N");a("autosubmit",c.autosubmit?"Y":"N");a("universalUnlock",c.universalUnlock?"Y":"N");a("concealPasswords",
c.concealPasswords?"Y":"N");a("tabUsedForGoAndFill",c.tabUsedForGoAndFill);a("useAnimation",c.useAnimation?"Y":"N");a("includeUsernameInAutosave",c.includeUsernameInAutosave?"Y":"N");b(c.doNotAutosaveOnDomains.split("\n"))},Va:function(){var a={};a.type=e("password_type","random");a.length=d("password_length",14);a.symbols=d("password_symbols",0);a.digits=d("password_digits",2);a.avoidAmb=d("password_avoidAmb",1)?g:j;a.allowRepeats=d("password_allowRepeats",1)?g:j;a.separator=e("password_separator",
"-");return a},Fb:function(b){b&&(a("password_type",b.type),a("password_length",""+b.length),a("password_symbols",""+b.symbols),a("password_digits",""+b.digits),a("password_avoidAmb",""+(b.avoidAmb?1:0)),a("password_allowRepeats",""+(b.allowRepeats?1:0)),a("password_separator",b.separator))},kb:function(a){for(var a=z.A(a),a=z.ha(a),d=c(),e=0,k=d.length;e<k;e++)if(d[e]==a)return;d.push(a);b(d)},$a:function(){return j},q:function(){a("autosave","N")}}}();UPDATE_URL_HASHES_BATCH_SIZE=200;
var z=function(){function b(){t&&clearTimeout(t);t=setTimeout(c,100)}function c(){if(!C.a()){var c=parseInt(ta.__VERSION__,10);D.ib(c,function(d){if(!C.a()){for(var d=d.result||[],e=Math.min(UPDATE_URL_HASHES_BATCH_SIZE,d.length),q=0;q<e;++q){var A=d[q],h=C.o(A.overview);if(h){var A=A.uuid,F=h.location,h=f(F),F=a(F);D.Qb(A,h,F,c)}else console.error("Failed to decrypt item: "+JSON.stringify(A))}e<d.length&&b()}})}}function a(a){if(""==a)return"0000";if(!a)return i;a=d(a);return SHA256.sha256_digest(D.J()+
a)}function d(a){if(!a)return i;a=h(a);if(!a||0==a.length)return"";a=m(a);return e(a)}function e(a){var b=a.split(".");if(2>b.length)return a;var c=b.pop(),d=ta[c];if(!d)return a;for(var a=b.join("."),e=d.e||[],f=0;f<e.length;++f){var h=e[f];if(!(a.length<=h.length)&&a.substr(-h.length-1)==="."+h)return h+"."+c}h=d.w||[];for(f=0;f<h.length;++f)if(e=h[f],!(a.length<=e.length)&&(0===e.length||a.substr(-e.length-1)==="."+e)){a=e.split(".").length+2;0===e.length&&(a=2);if(a>b.length)a=b.length;return b.splice(-a).join(".")+
"."+c}d=d.r||[];for(f=0;f<d.length;++f)if(e=d[f],!(a.length<=e.length)&&a.substr(-e.length-1)==="."+e){a=e.split(".").length+1;if(a>b.length)a=b.length;return b.splice(-a).join(".")+"."+c}return b.pop()+"."+c}function f(a){if(""==a)return"0000";if(!a)return i;a=h(a);a=m(a);return SHA256.sha256_digest(D.J()+a)}function h(a){var b=a.match(/^(?:f|ht)tp(?:s)?:\/\/([^/:]+)/im);return b?b[1].toString().toLowerCase():a}function m(a){if(!r){var b=ta.__TRANSFORMATIONS__;if(b){var c=[];try{for(var d=0;d<b.length;++d){var e=
b[d].match,f=b[d].result;e&&f&&c.push({match:RegExp(e),result:f})}}catch(h){console.error("[SETTINGS] Failed to parse domain rules: "+h.message)}r=c}else r=[]}for(b=0;b<r.length;++b)if(c=r[b].match,c.test(a)){a=a.replace(c,r[b].result);break}return a}var r=i,t=0;return{A:h,z:f,ha:e,jb:d,g:a,oa:b}}(),C=function(){function b(a,b,c){try{var d=y.Qa(b);return y.Ba(d,c,a)}catch(e){return console.log("Error during decryption: %s",e),i}}var c=i,a=i,d=i,e=i,f=i,h=i,m=i,r=i,t=i;return{D:function(b,p,f,q,h){c=
b;a=p;d=f;h=parseInt(h||"0",10);1E3>h&&(h=1E3);e=h},J:function(){return c},L:function(){return t},Sb:function(c){try{var p;var v=b(d,c,e);if(v)if(f=y.M(v,a)){h=v;var q=y.openSSLKey(f,[]);m=q.key;r=q.iv;p=g}else p=i;else p=i;p&&(t=c);return p}catch(A){return j}},o:function(a){a=y.Pa(m,r,y.Fa(a));a=sjcl.codec.utf8String.fromBits(a);return JSON.parse(a)},Z:function(a){a=y.Sa(m,r,sjcl.codec.utf8String.toBits(a));return y.Ha(a)},X:function(a){var b;try{var c=y.M(h,a);b=JSON.parse(sjcl.codec.utf8String.fromBits(c))}catch(d){console.error("[KEYCHAIN] Failed to decrypt: "+
d.message),b=i}return b},Ra:function(a){return y.N(h,sjcl.codec.utf8String.toBits(a))},a:function(){return h==i},Tb:b,lock:function(){t=r=m=f=h=i}}}(),D=function(){function b(a){var b={uuid:a.uuid,type_name:a.type_name,overview:a.overview,details:a.details,trashed:a.trashed,created_at:a.created_at,updated_at:a.updated_at,contents_hash:a.contents_hash};a.scope&&(b.scope=a.scope);a.derived_hash&&(b.derived_hash=a.derived_hash);a.naked_hash&&(b.naked_hash=a.naked_hash);a.hash_version&&(b.hash_version=
a.hash_version);a.autosave_token&&(b.autosave_token=a.autosave_token);a.folder_uuid&&(b.folder_uuid=a.folder_uuid);return b}function c(a,b){a.executeSql("SELECT uuid, overview_key, details_key, validation, iterations FROM keys",[],function(a,c){if(1==c.rows.length){var d=c.rows.item(0);b.key={uuid:d.uuid,overview_key:d.overview_key,details_key:d.details_key,validation:d.validation,iterations:d.iterations}}else 0==c.rows.length?console.warn("[DATASOURCE] Warning: no key found in keys table."):console.warn("[DATASOURCE] Warning: more than one key found in keys table.")})}
function a(a){t||(t=g,e.transaction(function(a){a.executeSql("CREATE TABLE IF NOT EXISTS keys (uuid TEXT PRIMARY KEY, overview_key TEXT, details_key TEXT, validation TEXT, iterations INTEGER)",[]);a.executeSql("CREATE TABLE IF NOT EXISTS items (uuid TEXT PRIMARY KEY, type_name TEXT, overview TEXT, derived_hash TEXT, naked_hash TEXT, hash_version INTEGER, details TEXT, scope TEXT, trashed TEXT, created_at INTEGER, updated_at INTEGER, contents_hash TEXT, autosave_token TEXT, folder_uuid TEXT)",[]);
a.executeSql("CREATE INDEX IF NOT EXISTS items_type_name_index on items (type_name, trashed)",[]);a.executeSql("CREATE TABLE IF NOT EXISTS config (name TEXT PRIMARY KEY, value TEXT, source TEXT)",[]);a.executeSql("INSERT OR REPLACE INTO config (name, value) VALUES (?, ?)",["buildnum","7"]);a.executeSql("INSERT OR REPLACE INTO config (name, value) VALUES (?, ?)",["version","3.9.0.b7"]);a.executeSql("INSERT OR IGNORE INTO config (name, value) VALUES (?, ?)",["uuid",f]);a.executeSql("INSERT OR IGNORE INTO config (name, value) VALUES (?, ?)",
["created_at",m])},function(a){console.error("Failed to initialize the database: "+a)},function(){a&&a(f)}))}function d(b,c){console.log("[DATASOURCE] Database version: "+b);7>b?(console.log("[DATASOURCE] Upgrading database version from "+b+" to 7"),e.transaction(function(a){4>b&&(a.executeSql("DROP TABLE IF EXISTS config"),a.executeSql("DROP TABLE IF EXISTS items"),a.executeSql("DROP TABLE IF EXISTS keys"));5>b&&(a.executeSql("ALTER TABLE items ADD COLUMN autosave_token TEXT"),a.executeSql("ALTER TABLE items ADD COLUMN folder_uuid TEXT"),
a.executeSql("DELETE FROM config WHERE name = 'uuid'"),f="dcd654f0bfd811e0962b0800200c9a66"+na.s());7>b&&(a.executeSql("DROP TABLE IF EXISTS domain_rules"),a.executeSql("ALTER TABLE items ADD COLUMN hash_version INTEGER"),a.executeSql("UPDATE items SET hash_version = 0"))},function(b){console.error("[DATASOURCE] Failed to upgrade database: %s",b?b.message:"unknown");a(c)},function(){a(c)})):a(c)}var e=i,f="dcd654f0bfd811e0962b0800200c9a66"+na.s(),h=i,m=(new Date).getTime()+"",r=i,t=j,k=i;return{D:function(b){if(e==
i){e=new WebDatabase("OnePassword","1.0","1Password Database");var c=-1;e.readTransaction(function(d){d.executeSql("SELECT name, value FROM config WHERE name in ('buildnum', 'uuid', 'version', 'created_at', 'server_database_id')",[],function(a,b){for(var d=0;d<b.rows.length;++d){var e=b.rows.item(d);"uuid"==e.name?f=e.value:"buildnum"==e.name?c=e.value:"version"==e.name?h=e.value:"created_at"==e.name?m=e.value:"server_database_id"==e.name&&(k=e.value)}},function(){a(b);c=0});d.executeSql("SELECT uuid FROM keys",
[],function(a,b){for(var c=0;c<b.rows.length;++c)r=b.rows.item(c).uuid},function(){a(b);c=0})},function(){a(b)},function(){0<c?d(c,b):0>c&&a(b)})}},tb:function(){return h},Oa:function(){return m},gb:function(a){if(!e&&a)a({error:"Extension database not available. Please press Command-Option-Q to restart your browser and discard invalid state."});else{var b={};e.readTransaction(function(a){c(a,b)},function(b){b="Database error 1: "+(b?b.message:b);console.error(b);0<b.indexOf(" is prohibited")&&(b=
"Please restart Safari with Cmd-Option-Q or disable-enable 1Password extension in Safari > Preferences > Extensions.<br><br><small>(Private Browsing mode bug)</small>");a&&a({error:b})},function(){a&&a(b)})}},Ab:function(a,b){e.transaction(function(b){b.executeSql("DELETE FROM keys",[]);b.executeSql("INSERT OR REPLACE INTO keys (uuid, overview_key, details_key, validation, iterations) values (?, ?, ?, ?, ?)",[a.uuid,a.overview_key,a.details_key,a.validation,a.iterations])},function(a){console.error("[DATASOURCE] Database error (saveEncryptionKey):"+
(a?a.message:a));b&&b({error:a?a.message:a})},function(){r=a.uuid;b&&b()})},Bb:function(a,b){e.transaction(function(b){a.scope==i&&(a.scope="Regular");a.hash_version||(a.hash_version=0);b.executeSql("INSERT OR REPLACE INTO items (uuid, type_name, overview, derived_hash, naked_hash, hash_version, details, scope, trashed, created_at, updated_at, contents_hash, autosave_token, folder_uuid) values (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)",[a.uuid,a.type_name,a.overview,a.derived_hash,a.naked_hash,a.hash_version,
a.details,a.scope,a.trashed,a.created_at,a.updated_at,a.contents_hash,a.autosave_token,a.folder_uuid]);b.executeSql("INSERT OR REPLACE INTO config (name, value) VALUES (?, ?)",["checksum","0"])},function(a){console.error("[DATASOURCE] Database error (saveItem):"+(a?a.message:a));b&&b({error:a?a.message:a})},function(){b&&b()})},Nb:function(a,d,f,h){var m={items:[]};e.transaction(function(e){for(var s=0;s<a.length;++s){var x=a[s];x.scope==i&&(x.scope="Regular");x.hash_version||(x.hash_version=0);e.executeSql("INSERT OR REPLACE INTO items (uuid, type_name, overview, derived_hash, naked_hash, hash_version, details, scope, trashed, created_at, updated_at, contents_hash, autosave_token, folder_uuid) values (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)",
[x.uuid,x.type_name,x.overview,"","",0,x.details,x.scope,x.trashed,x.created_at,x.updated_at,x.contents_hash,x.autosave_token,x.folder_uuid])}for(s=0;s<d.length;++s)e.executeSql("DELETE FROM items WHERE uuid=?",[d[s]]);c(e,m);for(s=0;s<f.length;++s)e.executeSql("SELECT * FROM items WHERE uuid=?",[f[s]],function(a,c){if(0<c.rows.length){var d=b(c.rows.item(0));m.items.push(d)}})},function(a){console.error("[DATASOURCE] Database error (syncData):"+(a?a.message:a));h&&h({error:a?a.message:a})},function(){h&&
h(m)})},H:function(a,b,c,d){var f=[],h=[],s=i,x=i;"*"!=c&&(s=z.z(c),x=z.g(c));e.readTransaction(function(c){var d="SELECT uuid, overview, derived_hash, naked_hash, hash_version, created_at, updated_at FROM items WHERE type_name=? AND trashed='N' AND scope <> 'Never'";b&&(d="SELECT uuid, overview, details, derived_hash, naked_hash, hash_version, created_at, updated_at FROM items WHERE type_name=? AND trashed='N' AND scope <> 'Never'");var e=[a];s&&(d+=" AND (derived_hash=? OR naked_hash=?)",e.push(s),
e.push(x));c.executeSql(d,e,function(a,c){for(var d=0;d<c.rows.length;d++){var e=c.rows.item(d),G={uuid:e.uuid,overview:e.overview,derived_hash:e.derived_hash,naked_hash:e.naked_hash,hash_version:e.hash_version,created_at:e.created_at,updated_at:e.updated_at};b&&(G.details=e.details);f.push(G);G.derived_hash==s&&h.push(G)}})},function(a){a="Database error 5: "+(a?a.message:a);console.error("[DATASOURCE] "+a);d&&d({error:a})},function(){d&&d({nakedMatch:f,derivedMatch:h})})},G:function(a,c){var d=
i;e.readTransaction(function(c){c.executeSql("SELECT * FROM items WHERE uuid=?",[a],function(a,c){for(var e=0;e<c.rows.length;e++)d=b(c.rows.item(e))})},function(a){console.error("[DATASOURCE] Database error 2: "+(a?a.message:a));c&&c({error:a?a.message:a})},function(){c&&c({result:d})})},Xb:function(a,d){var f={items:[]};e.readTransaction(function(d){c(d,f);for(var e=0;e<a.length;++e)d.executeSql("SELECT * FROM items WHERE uuid=?",[a[e]],function(a,c){var d=b(c.rows.item(0));f.items.push(d)})},function(a){console.error("[DATASOURCE] Database error (loadItemsForUUIDs): "+
(a?a.message:a));d&&d({error:a?a.message:a})},function(){d&&d(f)})},hb:function(a){var b={},d={hashes:b};e.readTransaction(function(a){c(a,d);a.executeSql("SELECT uuid, contents_hash FROM items",[],function(a,c){for(var d=0;d<c.rows.length;d++){var e=c.rows.item(d);b[e.uuid]=e.contents_hash}})},function(b){console.error("[DATASOURCE] Database error 6: "+(b?b.message:b));a&&a({error:b?b.message:b})},function(){a&&a(d)})},Cb:function(a,b){e.transaction(function(b){for(var c in a)a.hasOwnProperty(c)&&
b.executeSql("UPDATE items SET contents_hash=? WHERE uuid=?",[a[c],c])},function(a){console.error("[DATASOURCE] Database error (saveItemHashes): "+(a?a.message:a));b&&b({error:a?a.message:a})},function(){b&&b()})},ib:function(a,b){var c=[];e.transaction(function(b){b.executeSql("SELECT uuid, overview, hash_version FROM items WHERE hash_version < ? LIMIT 201",[a],function(a,b){for(var d=0;d<b.rows.length;d++){var e=b.rows.item(d),f={};f.uuid=e.uuid;f.overview=e.overview;f.hash_version=e.hash_version;
c.push(f)}})},function(a){console.error("[DATASOURCE] Database error in loadItemOverviewsWithURLHashVersionBelow: "+(a?a.message:a));b&&b({error:a?a.message:a})},function(){b&&b({result:c})})},Qb:function(a,b,c,d){e.transaction(function(e){e.executeSql("UPDATE items SET derived_hash=?, naked_hash=?, hash_version=? WHERE uuid=?",[b,c,d,a])},function(a){console.error("[DATASOURCE] Database error (updateItemURLHashes):"+(a?a.message:a))},function(){})},fb:function(a,b){var c=z.g(a);if(c){var d=[];e.readTransaction(function(a){a.executeSql("SELECT uuid, autosave_token FROM items WHERE naked_hash=?",
[c],function(a,b){for(var c=0;c<b.rows.length;c++){var e=b.rows.item(c);d.push({uuid:e.uuid,autosave_token:e.autosave_token})}})},function(a){console.error("[DATASOURCE] Database error (loadAutosaveTokensForURL): "+(a?a.message:a));b&&b({error:a?a.message:a})},function(){b&&b({result:d})})}else b({result:[]})},J:function(){return r},F:function(){return f},Hb:function(a){k||e.transaction(function(b){b.executeSql("INSERT OR REPLACE INTO config (name, value) VALUES (?, ?)",["server_database_id",a])},
function(a){console.error("Failed to set serverDatabaseID: "+a)},function(){k=a})},ra:function(){return k}}}(),L=function(){function b(){return!G||!H?j:g}function c(a){ga=i;K=g;v("unlock",{p:a})}function a(){b()?S?J.R("Failed to sync with helper"):J.R(i):J.R("Not connected to helper")}function d(){s+=1;s>=q.length&&(s=0,6E4>E&&(E+=2E3));var b="ws://127.0.0.1:"+q[s]+"/2";H&&(H.close(),H=i);K=N=j;pa=-1;H=new WebSocket(b);H||(console.error("[AGENT] Failed to connect to "+q[s]),e(s==q.length-1?E:50));
H.onerror=function(b){console.error("[AGENT] socket error: ",b);a()};H.onopen=function(){console.log("[AGENT] connected to port "+q[s]);v("hello",{k:sjcl.codec.hex.fromBits(x),enableUniversalUnlock:B.U()?"y":"n"});a()};H.onmessage=function(b){try{var c=y.M(x,b.data),d=sjcl.codec.utf8String.fromBits(c),e=JSON.parse(d);e?k(e):console.error("[AGENT] Failed to parse incoming message")}catch(f){console.error("[AGENT] Exception in onmessage: "+f)}a()};H.onclose=function(b){console.log("[AGENT] close: "+
b);G=i;a();e(s==q.length-1?E:50)};a()}function e(a){qa&&clearTimeout(qa);qa=setTimeout(d,a)}function f(){D.hb(function(a){m(g);var b={};b.hashes=a.hashes;b.key=a.key;D.ra()&&(b.serverDatabaseID=D.ra());C.L()&&(b.p=C.L());v("syncRequest",b)})}function h(a){K=j;var b=C.a()?i:C.L(),d=a.p;C.a()&&B.U()&&d&&J.j(d);a.locked?b&&c(b):p(100)}function m(a){K=j;if(a!=N)(N=a)?(I.completedAt=i,I.startedAt=new Date):(I.completedAt=new Date,z.oa())}function r(a,b,c,d){D.Nb(a,b,c,function(a){if(0==c.length)d?(m(j),
J.P()):p(100);else if(!a.error){a={key:a.key,requestedObjects:a.items};if(d)a.completed="Y",J.P();v("syncCompleteRequest",a)}})}function t(a,b){a?D.Ab(a,b):b()}function k(a){var b=parseInt(a.number||"0",10);if(b<=pa)console.error("Invalid incoming message");else if(pa=b,b=a.action,"heartbeat"===b)O.elapseTime=(new Date).getTime()-O.sentAt,O.count==a.payload.beats&&(O.acked=g);else if("welcome"===b)E=0,G=sjcl.codec.hex.toBits(a.payload.skey),b=a.payload.settings,B.ta(b),A=a.payload.diags,h(a.payload);
else if("activate"===b)J.t(g);else if("allLogins"===b)J.xa();else if("lock"===b)J.lock();else if("unlock"===b)h(a.payload);else if("unlockReply"===b)ga=a.payload.accepted,"N"==ga?K=j:(m(j),p(50));else if("setPreferences"===b)b=a.payload.settings,B.ta(b);else if("triggerSync"===b)p(1200*Math.random());else if("syncReply"===b)if(K=j,a=a.payload,a.error)S=a.error,console.error("[AGENT] syncReply error: "+S),m(j);else{S=i;m(g);var b=a.key,c=a.serverDatabaseID,d=a.updatedObjects||[],e=a.requestedUUIDs||
[],f=a.uuidsToDelete||[],s="Y"==a.completed;c&&D.Hb(c);t(b,function(){r(d,f,e,s)})}else if("syncCompleteReply"===b)a=a.payload,b=a.hashes,s="Y"==a.completed,D.Cb(b,function(){s?m(j):p(100)})}function p(a){ra&&clearTimeout(ra);ra=setTimeout(f,a)}function v(a,b){b||(b={});var c={action:a,number:++Na,version:"2",bundleId:F,payload:b},c=JSON.stringify(c),d=i;"hello"===a?(d=(new Date).getTime(),d=Math.floor(d/1E4),9==d%10&&(d+=1),d="Ds"+d+"y"+D.F()+"9",d=SHA256.sha256_digest(d),c=y.N(sjcl.codec.utf8String.toBits(d),
sjcl.codec.utf8String.toBits(c))):c=!G?i:y.N(G,sjcl.codec.utf8String.toBits(c));(d=c)&&H.send(d)}var q=[6258,10191,14821,24861,25007,38151,46360,49801,55730,59483],A={},E=0,F=i,s=0,x=i,G=i,Na=1,pa=-1,H=i,ga=i,K=j,N=j,S=i,I={completedAt:i,startedAt:i},O={timer:i,count:0,sentAt:i,acked:j,elapseTime:i},qa=0,ra=0;return{connect:function(a){F=a;x=sjcl.random.randomWords(8,0);G=i;s=-1;e(100)},j:c,lock:function(){v("lock",{})},Q:function(a){v("setPreferences",{autosave:a.autosave?"Y":"N",autosubmit:a.autosubmit?
"Y":"N"})},Na:function(a){if("object"==typeof clipboard)return clipboard.set(a),g;if("object"==typeof chrome){var b=document.createElement("input");b.type="text";b.value=a;document.body.appendChild(b);b.select();document.execCommand("copy");document.body.removeChild(b);return g}return L.c()?(v("copyToClipboard",{data:a}),g):j},rb:function(){v("pressEnterKey",{})},eb:function(){v("launch1Password",{})},Pb:function(a){r([],[],[a],g)},T:function(){var a="N/A";I.startedAt&&I.completedAt&&(a=I.completedAt.getTime()-
I.startedAt.getTime());var c="N/A";I.completedAt&&(c=I.completedAt.getTime());return{connected:b(),lastSyncError:S,diags:A,heartbeatAcked:O.acked,heartbeatElapseTime:O.elapseTime,heartbeatCount:O.count,heartbeatInterval:20,syncInProgress:N?"Yes":"No",syncCompletedAt:c,syncElapseTime:a}},Ob:function(){b()?N||K||f():z.oa()},ea:function(){return N},fa:function(){return K},ya:function(){return ga},l:function(){return S},yb:function(){if(!N)return 0;var a=I.startedAt;return!a?0:(new Date).getTime()-a.getTime()},
c:b}}(),ua=ja()?"http://help.agilebits.com/1Password_Windows/":"http://help.agilebits.com/1Password3/",va=i,J=function(){function b(a){"object"==typeof safari?(safari.application.activeBrowserWindow||safari.application.openBrowserWindow(),safari.application.activeBrowserWindow.openTab("foreground").url=c(a)):"object"==typeof chrome?chrome.tabs.create({url:c(a)}):"object"==typeof M?M.open(c(a)):console.error("[ONEPASSWORD] Browser not supported")}function c(a){return 0==a.indexOf("http://")||0==a.indexOf("https://")||
0==a.indexOf("safari-extension://")||0==a.indexOf("chrome-extension://")||0==a.indexOf("resource://")?a:0<=a.indexOf(":443")?"https://"+a:"http://"+a}function a(a,b){d(a,function(c){var d=c.derivedMatch,c=c.nakedMatch;p=i;d&&1===d.length?p=d[0].uuid:c&&1===c.length&&(p=c[0].uuid);p&&!C.a()?(r(i,a,p,i),setTimeout(function(){p&&(p=i,h("logins"))},900)):h("logins",b,p)})}function d(a,b){if(a==i&&"object"==typeof safari)a=safari.application.activeBrowserWindow.activeTab.url;if(a==i||void 0==a)a="";D.H("webforms.WebForm",
j,a,function(a){b({nakedMatch:a.nakedMatch,derivedMatch:a.derivedMatch,locked:g})})}function e(){if("object"==typeof safari)for(var a=0,b=safari.extension.popovers.length;a<b;a++){var c=safari.extension.popovers[a];c&&(c.hide(),safari.extension.removePopover(c.identifier))}}function f(a,b,c){P(i,"showPopup",{tab:a,locked:C.a(),fillLoginHotKeyUsed:b,fillLoginUuid:c})}function h(a,b,c){L.c()||L.connect();a==i&&(a="logins");if("object"==typeof safari){e();for(var d=safari.application.activeBrowserWindow,
h=0,m=safari.extension.toolbarItems.length;h<m;h++){var k=safari.extension.toolbarItems[h];if(k.browserWindow===d){a=safari.extension.createPopover("OnepasswordPopover",u("data/ui/popup.html?tab="+a+"&locked="+(C.a()?"yes":"no")+"&fillLoginHotKeyUsed="+(b?"yes":"no"))+(c?"&fillLoginUuid="+c:""),300,312);k.popover=a;k.showPopover();return}}}else if("object"!=typeof chrome){wa(a,C.a(),b,c).show();return}f(a,b,c)}function m(){if("object"==typeof safari)for(var a=0,b=safari.extension.toolbarItems.length;a<
b;++a)safari.extension.toolbarItems[a].badge=F?1:0;else"object"==typeof chrome?chrome.browserAction.setIcon({path:F?"data/images/toolbar-chrome-trouble.png":"data/images/toolbar-chrome.png"}):"object"==typeof Q&&Q.Ib(R.url(F?"images/toolbar-firefox-trouble.png":"images/toolbar-firefox.png"))}function r(a,b,c,d){D.G(c,function(c){if(c.result){c=c.result;xa(c);var f=B.d().autosubmit;P(a,"fillItem",{item:JSON.stringify(c),url:b,autosubmit:f,extensionBaseURL:u(""),pendingPasswordForIdentityFill:d});e()}})}
var t=0,k={},p=i,v=[],q={},A=(new Date).getTime(),E=i,F=i;goAndFillLoginWithUuid=function(a,d,f){if(!C.a()||!d)D.G(a,function(a){a=a.result;k[a.naked_hash]=a;if(d)if(xa(a),"NewTab"===f)b(a.location);else if("CurrentTab"===f)ya(a.location);else if("NewWindow"===f)if(a=a.location,"object"==typeof safari){var e=safari.application.openBrowserWindow();(e.activeTab?e.activeTab:e.openTab("foreground")).url=c(a)}else"object"==typeof chrome?chrome.windows.create({url:c(a)}):"object"==typeof za?za.open({url:c(a)}):
console.error("[ONEPASSWORD] Browser not supported");else console.log("[ONEPASSWORD] Invalid tabMode: "+f)}),e()};checkForGoAndFill=function(a,b){var c=k[z.g(a)];c?(!c.secureContents&&!C.a()&&xa(c),c.secureContents?b({item:JSON.stringify(c),url:a,autosubmit:B.d().autosubmit,extensionBaseURL:u("")}):(b({locked:g}),h("logins",g,c.uuid))):b({})};removePendingLoginWithUUID=function(a){p==a&&(p=i);for(var b in k)if(k.hasOwnProperty(b)&&k[b].uuid==a){delete k[b];break}};removePendingAutosavesForTabId=function(a){try{var b=
[],c;for(c in q)q.hasOwnProperty(c)&&q[c].tabId===a&&b.push(c);for(c=0;c<b.length;++c)delete q[b[c]]}catch(d){n(d)}};addPendingAutosave=function(a,b,c){c.autosaveId=b;c.tabId=a;q[b]=c;setTimeout(function(){"object"==typeof safari&&!c.fullscreen?T.Jb(c):"object"==typeof Q&&Q.Kb(b)},500)};neverAutosaveWithId=function(a,b){B.kb(q[a].location);L.Q(B.getAll());removeAutosaveWithId(a,b)};disableAutosave=function(){B.q();L.Q(B.getAll())};autosaveTokenForPasswordAndUUID=function(a,b){if(!a)return i;var c=
sjcl.codec.utf8String.toBits(b+a),d=sjcl.hash.sha256.hash(c),d=sjcl.bitArray.concat(d,c),d=sjcl.hash.sha256.hash(d),c=sjcl.bitArray.concat(d,c),c=sjcl.hash.sha256.hash(c),c=sjcl.codec.bytes.fromBits(c);return ba.Aa(c).toString(16)};autosaveIfLoginDoesNotExist=function(a,b,c){var d=b.location,e=new oa(b.login),f=e.Rb()||"",h=e.O(),m=z.jb(e.location());B.$a()&&0<f.length&&(m=m+" ("+f+")");e.setTitle(m);if(0===e.nb().length)c&&c({});else{var k=++t;C.a()?D.fb(d,function(d){if(d=d.result)for(var e=0;e<
d.length;++e)if(autosaveTokenForPasswordAndUUID(h,d[e].uuid)==d[e].autosave_token)return;addPendingAutosave(a,k,b);c&&c({tabId:a,autosaveId:k,locked:g})}):D.H("webforms.WebForm",g,d,function(d){for(var d=d.nakedMatch||[],f=0;f<d.length;f++){var h={secureContents:C.X(d[f].details)};if((new oa(h)).O()==e.O()){c({});return}}addPendingAutosave(a,k,b);c&&c({tabId:a,autosaveId:k})})}};scheduleAutosave=function(a,b,c){removePendingAutosavesForTabId(a);B.wa(b.location).autosave?autosaveIfLoginDoesNotExist(a,
b,c):c&&c({})};pendingAutosaveForTab=function(a,b,c){var d=i,b=z.g(b),e;for(e in q)if(q.hasOwnProperty(e)){var f=q[e];if(a&&a==f.tabId){d=f;break}if(!a&&b==z.g(f.location)){d=f;break}}c({tabId:a,autosave:d,locked:C.a()})};pendingAutosaveWithId=function(a,b){b({info:q[a],locked:C.a()})};removeAutosaveWithId=function(a,b){a&&delete q[a];b&&b({});"object"==typeof safari&&T.Za()};beginManualSave=function(){v=[]};considerLoginForManualSave=function(a){a&&v.push(a)};getPendingLoginForManualSave=function(){for(var a=
i,b=0,c=v.length;b<c;b++){var d=v[b];if(d&&(a==i||d.secureContents.fields.length>=a.secureContents.fields.length))a=d}v=[];a&&!a.uuid&&(a.uuid=na.s());return a};diagnostics=function(){return{version:"3.9.0.b7",instanceUUID:D.F().substring(0,8)+"..."+D.F().substring(60),uptime:(new Date).getTime()-A,databaseCreatedAt:D.Oa()}};showWelcomeScreenOrRestartIfNeeded=function(a){a===i?J.m(ua+"3_minute_expert_new.html"):"3.9.0.b7"!==a&&"com.apple.Safari"===U&&J.m(ua+"html/onepassword_extension_updated.html?currentVersion=3.9.0.b7&previousVersion="+
a)};allLoginsCache=function(){return C.a()?[]:E?E:[]};reloadAllLoginsCache=function(){E=i;Aa("webforms.WebForm","*",function(a){if(!a.locked){a=a.nakedMatch;E=[];for(var b=0,c=a.length;b<c;b++){var d=a[b];d.overview.location=ma(d.overview.location);d.overview.title=ma(d.overview.title);delete d.title;delete d.location;E.push(d)}"object"==typeof chrome&&V.f()}})};loginsForURLUsingCache=function(a){var b=z.z(a),c=z.g(a);return allLoginsCache().filter(function(a){return a.derived_hash===b||a.naked_hash===
c})};importBrowserLogins=function(){"object"!=typeof safari&&"object"!=typeof chrome&&"object"==typeof Q&&Q.C()};none=function(){};return{lock:function(){C.lock();k={};q={};E=i;Ba("lock",{});"object"==typeof chrome&&V.f()},j:function(a,b){D.gb(function(c){c.error?b({state:"UnlockDatabaseFailure",error:"Problem with database",errorMessage:c.error}):(c=c.key)?(C.D(c.uuid,c.overview_key,c.details_key,c.validation,c.iterations),c=C.Sb(a)?ca:da,b&&b({state:c}),c===ca&&(setTimeout(function(){reloadAllLoginsCache()},
10),setTimeout(function(){L.Ob()},200))):(c=ea,b&&b({state:c,error:"Data not available",errorMessage:"Please wait..."}))})},B:r,showPopover:h,Lb:f,removePopover:e,Ia:function(a,b){if("object"==typeof safari)for(var c=0,d=safari.extension.popovers.length;c<d;c++){var e=safari.extension.popovers[c];if(e)a.width&&(e.width=a.width),a.height&&(e.height=a.height),b&&b({})}},R:function(a){F=a;va&&(clearTimeout(va),va=i);a?va=setTimeout(function(){m()},1E3):m()},$b:function(){return F},t:function(b){if("object"==
typeof safari){var c=safari.application.activeBrowserWindow;if(c)(c=c.activeTab)&&a(c.url,b)}else if("object"==typeof chrome)chrome.windows.getLastFocused(function(c){chrome.tabs.getSelected(c.id,function(c){c&&a(c.url,b)})});else if("object"==typeof M)(c=M.activeTab)&&a(c.url,b)},xa:function(){h("logins")},m:b,Ea:allLoginsCache,P:reloadAllLoginsCache,K:loginsForURLUsingCache,i:goAndFillLoginWithUuid,Ja:checkForGoAndFill,xb:removePendingLoginWithUUID,wb:removePendingAutosavesForTabId,Db:scheduleAutosave,
ob:pendingAutosaveForTab,pb:pendingAutosaveWithId,ka:removeAutosaveWithId,ia:neverAutosaveWithId,q:disableAutosave,Ga:beginManualSave,Ma:considerLoginForManualSave,Wa:getPendingLoginForManualSave,Mb:showWelcomeScreenOrRestartIfNeeded,Y:diagnostics,C:importBrowserLogins}}(),T=function(){function b(){for(var a=0;a<safari.extension.bars.length;++a){var b=safari.extension.bars[a];c(b,i);b.hide(j)}}function c(a,b){if(a.contentWindow)a.contentWindow.removeAutosaveWithId=J.ka,a.contentWindow.neverAutosaveWithId=
J.ia,a.contentWindow.disableAutosave=J.q,a.contentWindow.unlockInGlobalPage=Ca,a.contentWindow.saveObject=Da,a.contentWindow.loadItemsOfType=Aa,a.contentWindow.loadObjectForUuid=Ea,a.contentWindow.setAutosaveInfo&&a.contentWindow.setAutosaveInfo(b,C.a())}return{ab:function(){safari.application.addEventListener("beforeNavigate",T.zb,g);safari.application.addEventListener("command",T.qb,j);safari.application.addEventListener("contextmenu",T.Ya,j);safari.application.addEventListener("message",T.Xa,j);
b()},Za:b,Jb:function(a){for(var b=j,e=0;e<safari.extension.bars.length;++e){var f=safari.extension.bars[e];if(f.browserWindow==safari.application.activeBrowserWindow){b=g;c(f,a);f.show(g);break}}if(!b){console.warn("[SAFARI] Failed to find the autosave bar to show, will display all");for(e=0;e<safari.extension.bars.length;++e)f=safari.extension.bars[e],c(f,a),f.show(g)}},Ya:function(a){if(C.a())a.contextMenu.appendContextMenuItem("onepassword-unlock","Unlock 1Password","showPopoverFromSafariContextMenu");
else{a.contextMenu.appendContextMenuItem("onepassword-contextmenu","1Password","showPopoverFromSafariContextMenu");for(var b=J.K(safari.application.activeBrowserWindow.activeTab.url),c=0,f=b.length;c<f;++c){var h=b[c];a.contextMenu.appendContextMenuItem(h.uuid,"  "+w(h.overview.title),"safariFillLoginContextMenu")}}},qb:function(a){"showPopover"===a.command&&J.showPopover("logins");"showPopoverFromSafariContextMenu"===a.command?J.Lb("logins"):"safariFillLoginContextMenu"===a.command&&J.B(safari.application.activeBrowserWindow.activeTab,
safari.application.activeBrowserWindow.activeTab.url,a.target.identifier)},zb:function(a){if(a&&a.url)if(0===a.url.indexOf("http://agilebits.com/extension/activate"))a.preventDefault(),setTimeout(J.t,50);else if(0===a.url.indexOf("http://agilebits.com/extension/all_logins"))a.preventDefault(),setTimeout(J.xa,50);else if(0===a.url.indexOf("http://agilebits.com/extension/lock"))a.preventDefault(),J.lock();else{var b=a.url.indexOf("onepasswdfill=");if(0<b){var c=a.url.substr(b+14),b=a.url.substring(0,
b-1);a.preventDefault();ya(b);c&&J.i(c,j,"CurrentTab")}}},Xa:function(a){try{W(a.target,a.name,a.message,function(b){b={uuid:a.message.uuid,result:b};a&&a.target&&a.target.page&&a.target.page.dispatchMessage("performCallback",b)})}catch(b){n(b)}}}}(),V=function(){function b(a,b){chrome.contextMenus.create({title:w(a.overview.title),parentId:b,contexts:["all"],onclick:function(b,c){J.B(c,c.url,a.uuid)}})}var c=i;return{Da:function(){chrome.extension.onRequest.addListener(function(a,b,c){try{a&&a.command?
X(b.tab,a.command,a.params,function(a){c&&c(a)}):a&&a.name&&(W(b.tab,a.name,a.message),c&&c({}))}catch(f){n(f)}})},Ca:function(){chrome.tabs.onUpdated.addListener(function(a,b,c){var a=c.url,f=a.indexOf("onepasswdfill=");0<f?(b=a.substr(f+14),chrome.tabs.update(c.id,{url:a.substring(0,f-1)},i),b&&J.i(b,j,"CurrentTab")):a===Fa&&"complete"===b.status&&J.showPopover(i,j,i)})},La:function(){chrome.omnibox.onInputStarted.addListener(function(){c=i});chrome.omnibox.onInputChanged.addListener(function(a,
b){var e=[];if(C.a())e.push({content:"Press Return to Unlock 1Password",description:"1Password is currently locked"});else if(0<a.length){var f=a.toLowerCase();c=i;for(var h=J.Ea(),m=0;m<h.length;++m){var r=h[m],t=w(r.overview.title),k=w(r.overview.location);t||(t="");k||(k="");var p=t.toLowerCase(),k=k.toLowerCase();if(0<=p.indexOf(f)||0<=k.indexOf(f))e.push({content:"Open "+t+"\n"+r.uuid,description:"<match>"+t.replace(/</gm,"&lt;").replace(/>/gm,"&gt;","gm").replace(/&/gm,"&amp;")+"</match> &lt;<url>"+
ka(k)+"</url>&gt;"}),1==e.length&&(c=r.uuid)}}b(e)});chrome.omnibox.onInputEntered.addListener(function(a){if(C.a()||""===a.trim())J.t();else{var a=a.split("\n"),b=i;(b=2===a.length?a[1]:c)?J.i(b,g,"CurrentTab"):J.t()}});chrome.omnibox.setDefaultSuggestion({description:"<url><match>1Password:</match></url><dim> type </dim>Login<dim> name or press </dim>Return<dim> to show 1Password popup.</dim>"})},f:function(){chrome.contextMenus.removeAll();C.a()?chrome.contextMenus.create({title:"Unlock 1Password",
contexts:["all"],onclick:function(){J.showPopover()}}):(chrome.contextMenus.create({title:"Open 1Password",contexts:["all"],onclick:function(){J.showPopover()}}),chrome.windows.getLastFocused(function(a){chrome.tabs.getSelected(a.id,function(a){if(a&&(a=a.url,!(a&&0===a.indexOf("chrome://"))&&(a=J.K(a),0!==a.length)))for(var c=chrome.contextMenus.create({title:"Fill Login",contexts:["all"]}),f=0,h=a.length;f<h;++f)b(a[f],c)})}))}}}(),Ga={},Ha=0,Fa="http://help.agilebits.com/1Password3/chrome_empty_tab.html";
function Ia(b){"object"==typeof safari?b(safari.application.activeBrowserWindow.activeTab.url):"object"==typeof chrome?chrome.windows.getLastFocused(function(c){chrome.tabs.getSelected(c.id,function(a){b(a.url)})}):"object"==typeof M&&b(M.activeTab.url)}
function P(b,c,a){try{if(a||(a={}),"object"==typeof safari){if(!b)b=safari.application.activeBrowserWindow.activeTab;b&&(b.page?b.page.dispatchMessage(c,a):console.error("Error: tab.page not available"))}else if("object"==typeof chrome)b&&0<=b.id?chrome.tabs.sendRequest(b.id,{name:c,message:a},function(){}):chrome.windows.getLastFocused(function(b){chrome.tabs.getSelected(b.id,function(b){0===b.url.indexOf("chrome://")?"chrome://newtab/"===b.url?chrome.tabs.update(b.id,{url:Fa}):chrome.tabs.create({url:Fa}):
chrome.tabs.sendRequest(b.id,{name:c,message:a},function(){})})});else if("object"==typeof M){if(!b)b=M.activeTab;for(var d=Ja(b),b=0;b<d.length;++b)d[b].port.emit("message",{name:c,message:a})}}catch(e){n(e)}}
function Ba(b,c){try{if("object"==typeof safari)for(var a=safari.application.browserWindows,d=0;d<a.length;++d)for(var e=a[d].tabs,f=0;f<e.length;++f)P(e[f],b,c);else if("object"==typeof chrome)chrome.windows.getAll({populate:g},function(a){for(var d=0,e=a.length;d<e;d++)for(var f=a[d],h=0,v=f.tabs.length;h<v;h++)chrome.tabs.sendRequest(f.tabs[h].id,{name:b,message:c},function(){chrome.extension.cb&&console.log("[GLOBAL] sendRequest Error: %s",chrome.extension.cb.message)})});else if("object"==typeof e){d=
0;for(f=e.length;d<f;++d)P(e[d],b,c)}}catch(h){n(h)}}function Ka(b){if("object"==typeof chrome)return b.id;var c=b.com_agilebits_id;if(!c)c=++Ha,b.com_agilebits_id=c;return c}function La(b){return"object"==typeof chrome?b?b.id:i:!b?i:b.com_agilebits_id}function xa(b){try{if(!C.a()){var c=C.o(b.overview);b.overview=c;b.title=c.title;b.location=c.location;b.secureContents=C.X(b.details);delete b.details}}catch(a){n(a)}}
function Da(b,c){try{if(C.a())c({locked:g,error:"Failed to save because 1Password is locked."});else{var a={};a.uuid=b.uuid?b.uuid:na.s();a.type_name=b.type_name;a.overview=b.overview?C.Z(JSON.stringify(b.overview)):C.Z(JSON.stringify({title:b.title,location:b.location}));b.folder_uuid&&(a.folder_uuid=b.folder_uuid);a.derived_hash=z.z(b.overview.location);a.naked_hash=z.g(b.overview.location);a.hash_version=ta.__VERSION__;a.details=C.Ra(JSON.stringify(b.secureContents));a.trashed=b.trashed||"N";a.scope=
"Regular";var d=Math.round((new Date).getTime()/1E3);a.created_at=b.created_at?b.created_at:d;a.updated_at=d;a.contents_hash="777";D.Bb(a,function(){J.P();c({})});setTimeout(function(){L.Pb(a.uuid)},100)}}catch(e){n(e)}}function Ma(b,c){var a=b.title,d=c.title;return!a?-1:!d?1:a.toLowerCase().localeCompare(d.toLowerCase())}function Oa(b,c){var a=b.created_at,d=c.created_at;return!d?-1:!a?1:d-a}
function Pa(b){if(!b)return"n/a";var c=(Math.round((new Date).getTime()/1E3)-b)/60;if(1>=c)return"just now";b=c/60;if(1>=b)return Math.round(c)+" min ago";c=b/24;if(1>=c)return Math.round(b)+" hours ago";b=c/7;if(2>=b)return Math.round(c)+" days ago";c=b/4.33;if(2>=c)return Math.round(b)+" weeks ago";b/=52;return 2>=b?Math.round(c)+" months ago":Math.round(b)+" years ago"}function Qa(b){return Pa(b.created_at)+" - "+b.title}
function Aa(b,c,a){if(C.a())a({locked:g,error:"Failed to load items because 1Password is locked."});else{if(c==i&&"object"==typeof safari)c=safari.application.activeBrowserWindow.activeTab.url;if(c==i||void 0==c)c="";"webforms.WebForm"!==b&&"passwords.Password"!==b&&(c="*");var d,e;"passwords.Password"===b?(d=Oa,e=Qa):(d=Ma,e=i);D.H(b,j,c,function(b){var c;c=b.nakedMatch;for(var m=e,r=d,t=0;t<c.length;t++){var k=c[t],p=C.o(k.overview);if(p)k.overview=p,k.title=k.overview.title,k.location=k.overview.location;
if(k.details)(p=C.o(k.details))&&(k.secureContents=p);m&&(k.display_title=m(k))}c=c.sort(r);b=b.derivedMatch.sort(d);a({nakedMatch:c,derivedMatch:b,locked:j})})}}function Ea(b,c){C.a()?c({locked:g,error:"Failed to load object because 1Password is locked."}):D.G(b,function(a){a=a.result;xa(a);c({object:a})})}
function Ca(b,c,a){(L.ea()||L.fa())&&!c&&16E3>L.yb()?a({state:ha}):J.j(b,function(d){var e=d.state;c&&e===da&&L.c()?(setTimeout(function(){L.j(b)},50),a({state:ea})):!c&&e===da&&L.c()&&"Y"==L.ya()&&L.l()?"serverDatabaseIDMismatch"==L.l()?a({state:ia,error:"1Password Database Mismatch",errorMessage:"Re-install the extension to fix this problem.",clearPassword:g}):"problemWithKeys.tryOldPassword"==L.l()?a({state:ia,error:"Master Password Changed",errorMessage:"Enter previous password to update the extension.",
clearPassword:g}):a({state:ia,error:L.l(),errorMessage:"Please ensure you have the latest version of the main 1Password app.",clearPassword:g}):e!==ea?(a(d),e===ca&&setTimeout(function(){L.j(b)},50)):L.c()?L.ea()||L.fa()?a({state:ha}):c?(setTimeout(function(){L.j(b)},50),a({state:ea})):"N"==L.ya()?a({state:da}):(console.error("[GLOBAL] Unknown performUnlock error"),a({state:ia,error:"Unknown error",errorMessage:"Please ensure you have the latest version of the main 1Password app."})):a({state:fa})})}
function X(b,c,a,d){if("loadItemsOfType"===c)Aa(a.type,a.url,d);else if("getPopupOptions"===c){var e=a.options;e.locked=C.a();e.agentIsConnected=L.c();e.settings=B.d();e.troubleshooting=L.c()&&!L.l()?"no":"yes";Ia(function(a){e.url=a;d({options:e})})}else if("saveSettings"===c)B.Gb(a.settings),d({}),setTimeout(function(){L.Q(a.settings)},100);else if("loadAllSettings"===c)d({settings:B.d(),locked:C.a(),agentIsConnected:L.c()});else if("loadSettingsForURL"===c){var c=B.wa(a.url),f=L.T();d({settings:c,
agent:f})}else if("changePopupSize"===c)J.Ia(a,d);else if("performUnlock"===c)Ca(a.p,a.userInitiated,d);else if("saveObject"===c)Da(a,d);else if("loadObjectForUuid"===c)Ea(a.uuid,d);else if("scheduleAutosave"===c)b=Ka(b),J.Db(b,a,d);else if("pendingAutosaveForTab"===c)J.ob(La(b),a.url,d);else if("pendingAutosaveWithId"===c)J.pb(a.autosaveId,d);else if("removeAutosaveWithId"===c)c=a.autosaveId,J.ka(c,d),Ba("removeAutosave",{autosaveId:c});else if("neverAutosaveWithId"===c)c=a.autosaveId,Ba("removeAutosave",
{autosaveId:c}),J.ia(c,d);else if("loadPasswordOptions"===c)d(B.Va());else if("savePasswordOptions"===c)B.Fb(a),d({});else if("performLock"===c)J.lock(),d&&d({}),B.U()&&setTimeout(function(){L.lock()},300);else if("loadDocument"===c){var c=a.documentUUID,f=a.documentURL,b=Ka(b),h=Ga[b];h||(h={});h[c]={documentURL:f,login:i};Ga[b]=h;d({tabId:b})}else if("unloadDocument"===c){c=a.documentUUID;if(b=La(b))(h=Ga[b])&&delete h[c];d({})}else if("considerLoginForManualSave"===c)J.Ma(a.login);else if("getPendingLoginForManualSave"===
c)d({result:J.Wa()});else if("isLocked"===c)d(C.a());else if("checkForGoAndFill"===c)J.Ja(a.url,d);else if("getTroubleshootingInfo"===c)c={},c.agent=L.T(),c.extension=J.Y(),c.settings=B.d(),d(c);else if("copyToClipboard"===c)d({copied:L.Na(a.data)});else return console.log("[GLOBAL] Unknown command: "+c),"Unknown"}
function W(b,c,a,d){if("perform"===c)X(b,a.command,a.params,function(a){d(a)});else if("cancelAll"===c)(a=La(b))&&J.wb(a),P(b,"cancelAll"),J.removePopover();else if("launch1Password"===c)L.c()?L.eb():"object"==typeof safari&&navigator.userAgent.match(/OS X/)&&Ra();else if("showTroubleshootingReport"===c){b="data/ui/troubleshooting.html";"object"==typeof Sa&&(b="ui/troubleshooting.html");c=u(b);if("object"==typeof Sa)var b=escape(escape(JSON.stringify(L.T()))),a=escape(escape(JSON.stringify(J.Y()))),
e=escape(escape(JSON.stringify(B.d()))),c=c+("?agent="+b+"&extension="+a+"&settings="+e);J.m(c);J.removePopover()}else if("goAndFillLoginWithUuid"==c)J.i(a.uuid,g,B.d().tabUsedForGoAndFill);else if("fillItemWithUuid"==c)e=a.uuid,c=a.url,J.B(b,c,e,a.pendingPasswordForIdentityFill);else if("removePendingLoginWithUUID"===c)J.xb(a.uuid);else if("beginManualSave"==c)J.Ga(),P(b,"collectForms");else if("disableAutosave"===c)J.q();else if("pressEnterKey"==c)L.rb();else if("showUserGuide"==c)b=ja()?"http://help.agilebits.com/1Password_Windows/after-installing-JSE.html":
"http://help.agilebits.com/1Password3/3_minute_expert_new.html",J.m(b),J.removePopover();else if("unloadDocument"===c){if(c=a.documentUUID,a=La(b))(b=Ga[a])&&delete b[c]}else"importBrowserLogins"===c&&J.C()}function Ra(){if("object"==typeof safari){var b=safari.application.activeBrowserWindow.openTab("background");b.url="x-onepassword://";setTimeout(function(){b.close()},5)}}
function ya(b){if("object"==typeof safari)safari.application.activeBrowserWindow.activeTab.url=b;else if("object"==typeof chrome)chrome.tabs.getSelected(i,function(c){chrome.tabs.update(c.id,{url:b},i)});else if("object"==typeof M)M.activeTab.url=b}var U=i;
if("object"==typeof safari)U="com.apple.Safari",T.ab();else if("object"==typeof chrome)U="com.google.Chrome",V.La(),V.Da(),V.Ca(),V.f(),chrome.tabs.onSelectionChanged.addListener(function(){V.f()}),chrome.tabs.onUpdated.addListener(function(){V.f()});else{var U="org.mozilla.firefox",Ta=require("api-utils/preferences-service");"aurora"==Ta.get("app.update.channel")&&(U="org.mozilla.aurora");"nightly"==Ta.get("app.update.channel")&&(U="org.mozilla.nightly")}
if("object"==typeof window)window.performCommand=X,window.handleMessageEvent=W;setTimeout(function(){D.D(function(){J.Mb(D.tb());L.connect(U)})},100);
var ta={"فلسطين":{},bs:{r:["com","net","org","edu","gov"]},hk:{r:"組织,組織,组织,网絡,網絡,组織,公司,教育,敎育,政府,网络,个人,箇人,網络,個人,org,net,idv,gov,edu,com".split(",")},kh:{w:[""]},"இந்தியா":{},bt:{r:["com","edu","gov","net","org"]},ki:{r:"info,org,net,biz,gov,edu,com".split(",")},ne:{},qa:{w:[""]},ru:{r:"yuzhno-sakhalinsk,yekaterinburg,chelyabinsk,vladivostok,novosibirsk,krasnoyarsk,joshkar-ola,vladikavkaz,arkhangelsk,pyatigorsk,khabarovsk,astrakhan,bashkiria,volgograd,yaroslavl,tsaritsyn,rubtsovsk,stavropol,kamchatka,tatarstan,khakassia,chuvashia,chukotka,dagestan,vladimir,nakhodka,simbirsk,buryatia,belgorod,kustanai,mordovia,voronezh,kalmykia,kostroma,smolensk,k-uralsk,ulan-ude,udmurtia,orenburg,kemerovo,sakhalin,magnitka,murmansk,nalchik,karelia,yakutia,ivanovo,irkutsk,dudinka,bryansk,lipetsk,magadan,norilsk,mari-el,vologda,adygeya,fareast,kuzbass,izhevsk,saratov,mosreg,marine,kurgan,tyumen,tambov,koenig,surgut,palana,amursk,e-burg,baikal,syzran,vdonsk,ryazan,vyatka,samara,kaluga,grozny,jamal,pskov,yamal,penza,oryol,oskol,altai,chita,tomsk,kursk,kuban,mytis,kazan,kirov,zgrad,komi,kchr,tuva,tula,mari,chel,amur,nnov,omsk,perm,tver,test,vrn,udm,tsk,tom,stv,spb,cmw,rnd,ptz,kms,nsk,nov,msk,khv,gov,cbg,nkz,bir,mil,org,net,snz,int,edu,com,jar,pp,ac".split(",")},"الاردن":{},
us:{r:"paroch.k12.ma,stuff-4-sale,land-4-sale,chtr.k12.ma,pvt.k12.ma,k12.mn,lib.wy,lib.wv,lib.wi,lib.wa,lib.va,lib.vt,lib.vi,lib.ut,lib.tx,lib.tn,lib.sd,lib.sc,lib.ri,lib.pr,lib.pa,lib.or,lib.ok,lib.oh,lib.ny,lib.nv,lib.nm,lib.nj,lib.nh,lib.ne,lib.nd,lib.nc,lib.mt,lib.ms,lib.mo,lib.mn,lib.mi,lib.me,lib.md,lib.ma,lib.la,lib.ky,k12.wy,lib.in,lib.il,lib.id,lib.ia,lib.hi,lib.gu,lib.ga,lib.fl,lib.de,lib.dc,lib.ct,lib.co,lib.ca,lib.az,lib.as,lib.ar,lib.al,k12.ak,k12.al,k12.ar,k12.as,k12.az,k12.ca,k12.co,k12.ct,k12.dc,k12.de,k12.fl,k12.ga,k12.gu,k12.ia,k12.id,k12.il,k12.in,k12.ks,k12.ky,k12.la,k12.ma,k12.md,k12.me,k12.mi,lib.ak,k12.mo,k12.ms,k12.mt,k12.nc,k12.nd,k12.ne,k12.nh,k12.nj,k12.nm,k12.nv,k12.ny,k12.oh,k12.ok,k12.or,k12.pa,k12.pr,k12.ri,k12.sc,k12.sd,k12.tn,k12.tx,k12.ut,k12.vi,k12.vt,k12.va,k12.wa,k12.wi,k12.wv,lib.ks,cc.ak,is-by,cc.ar,cc.as,cc.az,cc.ca,cc.co,cc.ct,cc.dc,cc.de,cc.fl,cc.ga,cc.gu,cc.hi,cc.ia,cc.id,cc.il,cc.in,cc.ks,cc.ky,cc.la,cc.ma,cc.md,cc.me,cc.mi,cc.mn,cc.mo,cc.ms,cc.mt,cc.nc,cc.nd,cc.ne,cc.nh,cc.nj,cc.nm,cc.nv,cc.ny,cc.oh,cc.ok,cc.or,cc.pa,cc.pr,cc.ri,cc.sc,cc.sd,cc.tn,cc.tx,cc.ut,cc.vi,cc.vt,cc.va,cc.wa,cc.wi,cc.wv,cc.wy,cc.al,kids,isa,fed,dni,nsn,de,vi,ut,tx,tn,sd,sc,ri,pr,pa,or,ok,oh,ny,nv,nm,nj,nh,ne,nd,nc,mt,ms,mo,mn,mi,me,md,ma,la,ky,ks,in,il,id,ia,hi,gu,ga,fl,vt,dc,ct,co,ca,az,as,ar,al,ak,va,wa,wi,wv,wy".split(",")},
hm:{},nf:{r:"store,other,info,firm,arts,web,rec,per,net,com".split(",")},er:{w:[""]},hn:{r:"com,edu,org,net,mil,gob".split(",")},ng:{r:"org,com,edu,net,gov,ac".split(",")},rw:{r:"gouv,com,edu,mil,net,int,gov,ac,co".split(",")},asia:{},bw:{r:["org","co"]},es:{r:["com","nom","org","gob","edu"]},biz:{r:"for-better,for-some,for-more,for-the,dyndns,selfip,webhop".split(",")},ac:{r:"com,edu,gov,net,mil,org".split(",")},et:{w:[""]},ni:{w:[""]},"السعودية":{},ad:{r:["nom"]},by:{r:["gov","mil","com","of"]},
pro:{r:"aca,bar,cpa,jur,law,med,eng".split(",")},eu:{},km:{r:"pharmaciens,veterinaire,notaires,medecin,presse,gouv,asso,coop,com,ass,mil,edu,org,nom,gov,prd,tm".split(",")},tc:{},ae:{r:"mil,net,org,gov,sch,ac,co".split(",")},bz:{r:["com","net","org","edu","gov"]},hr:{r:["name","from","com","iz"]},kn:{r:["net","org","edu","gov"]},"भारत":{},td:{},af:{r:["gov","com","org","net","edu"]},nl:{r:["bv","co"]},uy:{w:[""]},ag:{r:["com","org","nom","net","co"]},ht:{r:"perso,adult,firm,info,shop,gouv,asso,coop,med,art,org,pol,pro,edu,rel,net,com".split(",")},
kp:{r:"com,edu,gov,org,rep,tra".split(",")},"السعودیۃ":{},uz:{r:["com","co"]},tf:{},ga:{},hu:{r:"konyvelo,ingatlan,erotika,erotica,tozsde,utazas,reklam,jogasz,casino,video,agrar,lakas,media,sport,forum,hotel,games,film,city,bolt,2000,info,suli,priv,szex,shop,news,org,sex,tm,co".split(",")},tg:{},ai:{r:["off","com","net","org"]},de:{r:"fuettertdasnetz,traeumtgerade,isteingeek,leitungsen,lebtimnetz,istmein,com".split(",")},kr:{r:"gyeongbuk,gyeongnam,chungbuk,gyeonggi,chungnam,jeonbuk,incheon,jeonnam,daejeon,gangwon,gwangju,daegu,seoul,busan,ulsan,jeju,mil,kg,or,ne,ms,sc,pe,hs,re,go,es,co,ac".split(",")},
"ایران":{},th:{r:"net,in,go,co,mi,ac,or".split(",")},no:{r:"herøy.møre-og-romsdal,sande.møre-og-romsdal,sande.more-og-romsdal,heroy.more-og-romsdal,nååmesjevuemie,stjørdalshalsen,stjordalshalsen,evje-og-hornnes,mátta-várjjat,våler.østfold,aurskog-høland,herøy.nordland,sande.vestfold,naamesjevuemie,hámmárfeasta,midtre-gauldal,heroy.nordland,øystre-slidre,våler.hedmark,aurskog-holand,kárášjohka,guovdageaidnu,oystre-slidre,dielddanuorri,báhccavuotna,nore-og-uvdal,brønnøysund,ráhkkerávju,giehtavuoatna,vestre-slidre,divttasvuotna,sandnessjøen,valer.ostfold,valer.hedmark,sør-varanger,skedsmokorset,matta-varjjat,davvenjárga,sor-varanger,gs.jan-mayen,leaŋgaviika,sandnessjoen,vestre-toten,čáhcesuolo,hattfjelldal,málatvuopmi,søndre-land,ákŋoluokta,báhcavuotna,nesoddtangen,divtasvuodna,hammarfeasta,østre-toten,krokstadelva,laakesvuemie,bø.nordland,os.hordaland,bø.telemark,kristiansand,kristiansund,nes.akershus,bahccavuotna,gáŋgaviika,nes.buskerud,bearalváhki,nord-aurdal,bådåddjå,bearalvahki,davvenjarga,fredrikstad,lillehammer,nordre-land,rahkkeravju,krødsherad,bronnoysund,nedre-eiker,bo.telemark,bo.nordland,stor-elvdal,ostre-toten,flekkefjord,øvre-eiker,kongsvinger,tvedestrand,hægebostad,vestvågøy,bahcavuotna,gs.svalbard,holmestrand,vossevangen,sondre-land,sør-aurdal,malatvuopmi,evenášši,leangaviika,fylkesbibl,masfjorden,spjelkavik,davvesiida,sor-aurdal,namdalseid,cahcesuolo,hjelmeland,namsskogan,båtsfjord,sandefjord,omasvuotna,ullensvang,gáivuotna,kvænangen,brumunddal,ullensaker,kvinnherad,aknoluokta,vindafjord,gangaviika,álaheadju,gildeskål,krodsherad,vegårshei,kautokeino,nøtterøy,lørenskog,hammerfest,karasjohka,balestrand,os.hedmark,jørpeland,kråanghke,porsáŋgu,hagebostad,høylandet,mjøndalen,ovre-eiker,snillfjord,jan-mayen,øygarden,mjondalen,overhalla,langevåg,audnedaln,hoylandet,porsanger,porsgrunn,kraanghke,rakkestad,austevoll,austrheim,randaberg,oppegård,andasuolo,ballangen,hyllestad,ringerike,balsfjord,jorpeland,gratangen,høyanger,ringsaker,hønefoss,nordreisa,trøgstad,hornindal,kongsberg,trondheim,songdalen,rælingen,holtålen,berlevåg,gildeskal,spydeberg,nord-odal,tjeldsund,nord-fron,alaheadju,bjerkreim,tønsberg,sørreisa,kvinesdal,alstahaug,stavanger,kviteseid,kvæfjord,bremanger,várggát,brønnøy,steinkjer,samnanger,mo-i-rana,návuotna,gaivuotna,skånland,stjørdal,åkrehamn,nannestad,vevelstad,storfjord,haugesund,batsfjord,vegarshei,flatanger,sykkylven,sarpsborg,skjervøy,drangedal,folkebibl,stathelle,leikanger,leirfjord,sør-fron,vestvagoy,lillesand,lindesnes,lødingen,eigersund,sør-odal,kvanangen,lorenskog,marnardal,rennesøy,engerdal,evenassi,sor-odal,meråker,eidsvoll,lodingen,moåreke,eidsberg,sørfold,levanger,sorreisa,eidfjord,moskenes,målselv,sor-fron,flakstad,surnadal,akrehamn,flesberg,lavangen,vennesla,ålgård,stjordal,kåfjord,narviika,navuotna,naustdal,hjartdal,svalbard,nesodden,kvafjord,kvitsøy,unjárga,badaddja,fyresdal,nissedal,nittedal,egersund,bjarkøy,tingvoll,kvalsund,birkenes,sortland,berlevag,nordkapp,báidár,gjerdrum,gjerstad,troandin,kragerø,trogstad,hokksund,bájddar,honefoss,notodden,notteroy,jessheim,grimstad,oppegard,kirkenes,kopervik,karasjok,jølster,jevnaker,inderøy,osterøy,langevag,oygarden,hoyanger,tysfjord,porsangu,rendalen,rennesoy,vågsøy,tonsberg,ralingen,rømskog,holtalen,røyrvik,salangen,ålesund,mosjøen,aarborte,orkanger,skanland,tananger,hemsedal,skiervá,sauherad,skiptvet,skjervoy,vanylven,steigen,royrvik,vaksdal,romskog,rødøy,siellak,saltdal,sálát,harstad,alesund,vestnes,agdenes,åfjord,kommune,ringebu,hápmir,rennebu,hábmer,sandnes,hamaroy,tysvær,sandøy,vaapste,aremark,ibestad,inderoy,arendal,iveland,åseral,stavern,jolster,askvoll,seljord,skedsmo,granvin,karlsoy,slattum,gálsá,osteroy,karmøy,råholt,aurland,ørskog,værøy,ørland,gloppen,gjøvik,kragero,averøy,gjesdal,gjemnes,skierva,gausdal,øksnes,osøyro,bálát,tromsø,nærøy,tranøy,bajddar,kvitsoy,mosjoen,norddal,torsken,bjarkoy,froland,skánit,budejju,unjarga,kafjord,forsand,folldal,nesseby,leirvik,sorfold,lavagis,bronnoy,loabát,lebesby,gs.oslo,bygland,bievát,snåase,leksvik,sogndal,finnøy,drammen,sokndal,malselv,svelvik,fetsund,sunndal,fuoisku,fuossko,modalen,lindås,varggat,midsund,eidskog,láhppi,stranda,moareke,elverum,meraker,drøbak,lyngdal,enebakk,stordal,etnedal,muosát,lærdal,måsøy,farsund,røyken,evenes,stokke,løten,malvik,algard,fauske,muosat,lerdal,mandal,marker,lardal,lyngen,meland,meldal,melhus,luster,meløy,lurøy,strand,lunner,lahppi,suldal,verran,lindas,stange,lierne,dønna,florø,mosvik,verdal,solund,dyrøy,søgne,finnoy,aejrie,namsos,lenvik,bømlo,sømna,fitjar,bievat,narvik,bærum,royken,snoasa,fjaler,loabat,snåsa,larvik,sørum,fosnes,deatnu,nesset,smøla,tjøme,skanit,frosta,bindal,fræna,bergen,tranoy,baidar,frøya,beiarn,osoyro,ráisa,beardu,skodje,skjåk,tromso,bamble,førde,gamvik,oksnes,gaular,oppdal,tromsa,gjovik,orkdal,orland,klæbu,orskog,trysil,raholt,ørsta,averoy,træna,vågan,karmoy,voagat,tynset,åsnes,sirdal,askøy,siljan,sigdal,vagsoy,vågå,vardø,jondal,hadsel,aseral,vestby,halden,tysnes,tranby,radøy,årdal,tysvar,ruovat,sandoy,habmer,andøy,hapmir,afjord,andebu,rindal,hvaler,hurdal,horten,utsira,hareid,risør,sálat,rollag,hasvik,vadsø,idrett,áltá,museum,hobøl,alvdal,hemnes,røros,drobak,snaase,røst,hitra,roros,rodoy,valle,råde,hobol,hemne,åmli,salat,rygge,vadso,risor,rissa,haram,åmot,andoy,rauma,ardal,ulvik,radoy,sauda,asker,askim,selbu,selje,øyer,hurum,askoy,asnes,skaun,aukra,vardo,skien,herad,hamar,orsta,balat,halsa,skjak,naroy,bardu,raisa,vefsn,bjugn,gulen,smola,bodø,grong,snasa,nesna,bykle,barum,bomlo,dovre,dyroy,tydal,donna,galsa,floro,molde,modum,meloy,grane,bryne,vagan,masoy,loten,gs.vf,stord,trana,gs.va,gs.tr,luroy,klepp,stryn,klabu,loppa,varoy,fedje,gs.tm,sveio,romsa,gs.st,sogne,lesja,somna,giske,gs.sf,gs.rl,fjell,gs.ol,gs.of,gs.nt,gs.nl,gs.mr,gs.hm,gs.hl,gs.fm,gs.bu,flora,gs.ah,gs.aa,vikna,sorum,forde,froya,frana,tolga,volda,tjome,frogn,tokke,voss,oslo,tinn,time,frei,tana,fusa,flå,kvam,leka,lier,sund,sula,lund,ivgu,gran,arna,etne,moss,sola,bokn,grue,vaga,bodo,berg,odda,osen,aure,oyer,stat,priv,rana,amot,roan,hole,vega,amli,alta,rade,vang,rost,fhs,sel,lom,ski,hå,vgs,hol,hof,gol,fla,fet,eid,ås,ål,mil,dep,vik,tr,tm,va,st,sf,rl,ol,of,nt,nl,mr,hm,hl,fm,bu,ah,aa,vf,al,ha,co".split(",")},
za:{w:[""]},gd:{},np:{w:[""]},xxx:{},tj:{r:"test,name,org,com,edu,web,gov,nic,mil,biz,net,int,go,co,ac".split(",")},ge:{r:"com,edu,gov,org,mil,net,pvt".split(",")},al:{r:"com,edu,gov,mil,net,org".split(",")},tk:{},gf:{},nr:{r:"info,edu,gov,biz,org,net,com".split(",")},am:{},__TRANSFORMATIONS__:[{result:"td.com",match:".*\\.(td|tdcanadatrust)\\.com$"},{result:"dropbox.com",match:".*\\.(dropbox|getdropbox)\\.com$"},{result:"citi.com",match:".*\\.(citi|citibank|citicards)\\.com$"},{result:"microsoft.com",
match:".*\\.(live|passport|msn|hotmail|microsoft)\\.com$"},{result:"37signals.com",match:".*\\.(37signals|basecamphq|backpackit|campfirenow|highrisehq)\\.com$"},{result:"$1agilebits.com",match:"(.*\\.)?(agile\\.ws|agilewebsolutions\\.com)$"}],tl:{r:["gov"]},kw:{w:[""]},an:{r:["com","net","org","edu"]},dj:{},"السعوديه":{},"بھارت":{},tm:{},gg:{r:["gov","org","sch","net","co"]},ao:{r:"ed,gv,og,co,pb,it".split(",")},dk:{},"გე":{},tn:{r:"tourism,defense,agrinet,edunet,mincom,turen,perso,rnrt,intl,info,net,org,ind,nat,rns,rnu,gov,fin,ens,com".split(",")},
je:{r:["gov","org","sch","net","co"]},ma:{r:"press,net,gov,org,ac,co".split(",")},ky:{r:["edu","gov","com","org","net"]},nu:{r:["merseine","shacknet","mine"]},museum:{r:"correios-e-telecomunicações,posts-and-telecommunications,environmentalconservation,naturalhistorymuseum,colonialwilliamsburg,natuurwetenschappen,medizinhistorisches,sciencesnaturelles,harvestcelebration,scienceandindustry,telekommunikation,historicalsociety,naturhistorisches,scienceandhistory,nationalheritage,usdecorativearts,historyofscience,americanantiques,philadelphiaarea,museumvereniging,brandywinevalley,nationalfirearms,watch-and-clock,coloradoplateau,uscountryestate,computerhistory,childrensgarden,britishcolumbia,hembygdsforbund,uslivinghistory,oceanographique,science-fiction,contemporaryart,botanicalgarden,naturalsciences,stateofdelaware,comunicações,sciencecenters,communications,sciencehistory,kunstunddesign,archaeological,soundandvision,coastaldefence,casadelamoneda,christiansburg,decorativearts,historichouses,heimatunduhren,nativeamerican,naturalhistory,ירושלים,culturalcenter,sciencecenter,chesapeakebay,watchandclock,beeldengeluid,oceanographic,kunstsammlung,livinghistory,imageandsound,communication,southcarolina,countryestate,artsandcrafts,farmequipment,assassination,botanicgarden,indianapolis,saskatchewan,museumcenter,newhampshire,contemporary,intelligence,arteducation,indianmarket,williamsburg,preservation,artanddesign,schlesisches,santabarbara,architecture,encyclopedic,sanfrancisco,fortmissoula,stpetersburg,anthropology,franziskaner,localhistory,civilization,riodejaneiro,civilisation,illustration,philadelphia,salvadordali,historisches,chiropractic,surgeonshall,washingtondc,oregontrail,educational,photography,grandrapids,chattanooga,environment,agriculture,judygarland,delmenhorst,planetarium,midatlantic,schokoladen,schoenbrunn,interactive,volkenkunde,timekeeping,palmsprings,corporation,archaeology,freemasonry,americanart,lewismiller,gemological,association,historical,historisch,collection,humanities,resistance,monticello,foundation,motorcycle,cheltenham,california,copenhagen,zoological,portlligat,lancashire,savannahga,birthplace,sherbrooke,plantation,artgallery,vlaanderen,losangeles,luxembourg,capebreton,cartoonart,television,halloffame,technology,koebenhavn,marylhurst,exhibition,saintlouis,cincinnati,juedisches,usantiques,steiermark,journalism,pittsburgh,university,entomology,automotive,manchester,eastafrica,embroidery,elvendrell,settlement,versailles,eisenbahn,stockholm,education,eastcoast,jewishart,jerusalem,stuttgart,discovery,australia,jefferson,westfalen,isleofman,ethnology,newjersey,baltimore,starnberg,astronomy,karikatur,newmexico,farmstead,southwest,beauxarts,filatelia,newspaper,cranbrook,philately,artcenter,botanical,arboretum,nuernberg,nuremberg,fortworth,broadcast,francaise,frankfurt,yorkshire,santacruz,annefrank,community,amsterdam,minnesota,furniture,bruxelles,americana,ambulance,geelvinck,mesaverde,ushistory,cambridge,transport,paderborn,usculture,chocolate,childrens,rochester,barcelona,guernsey,иком,airguard,settlers,pasadena,scotland,american,pharmacy,helsinki,yosemite,heritage,histoire,antiques,aquarium,workshop,windmill,fundacio,asmatart,wildlife,horology,sciences,fribourg,freiburg,aviation,flanders,nebraska,naumburg,finearts,baseball,figueres,bellevue,stalbans,berkeley,wallonie,epilepsy,national,children,egyptian,donostia,dinosaur,portland,mulhouse,muenster,muenchen,delaware,montreal,svizzera,monmouth,database,presidio,missoula,cultural,creation,brussels,railroad,research,corvette,military,building,computer,michigan,columbus,memorial,columbia,usgarden,topology,cadaques,sandiego,maryland,salzburg,loyalist,maritimo,civilwar,maritime,undersea,mansions,mallorca,virginia,mansion,rockart,chicago,marburg,trustee,lucerne,clinton,castres,carrier,medical,trolley,coldwar,lincoln,burghof,larsson,santafe,convent,lajolla,railway,costume,theater,missile,culture,project,textile,brussel,schweiz,ushuaia,science,british,bristol,denmark,pacific,judaica,village,detroit,jewelry,birdart,virtual,england,virtuel,jamison,station,bergbau,farmers,fineart,western,baghdad,badajoz,finland,whaling,indiana,florida,sologne,atlanta,history,newport,gallery,newyork,phoenix,norfolk,artdeco,society,gateway,geology,georgia,giessen,sibenik,zoology,seaport,alabama,ontario,openair,handson,hamburg,academy,oxford,alaska,oregon,palace,anthro,online,panama,assisi,austin,bauern,berlin,bilbao,boston,niepce,viking,pilots,botany,nature,vantaa,plants,valley,portal,museet,muncie,moscow,brasil,brunel,bushey,modern,public,canada,quebec,mining,miners,castle,meeres,usarts,celtic,madrid,center,russia,cinema,garden,luzern,louvre,london,living,circus,torino,county,landes,crafts,labour,dallas,sydney,sweden,school,design,karate,suisse,durham,jewish,elburg,stjohn,indian,estate,hellas,health,hawaii,exeter,family,square,surrey,salem,otago,amber,skole,glass,youth,force,paleo,field,space,paris,shell,stadt,omaha,gorge,state,basel,house,steam,essex,baths,wales,bible,dolls,north,neues,depot,naval,koeln,kunst,music,plaza,labor,money,cymru,texas,cyber,press,pubol,media,uhren,läns,touch,trust,clock,juif,coal,town,linz,cody,glas,silk,roma,frog,manx,lans,mill,time,film,satx,york,moma,dali,utah,uvic,arts,tank,farm,kids,tree,bonn,iraq,axis,bahn,bern,iron,bale,graz,nyny,bill,war,nyc,jfk,nrw,ddr,spy,tcm,art,bus,can,and,usa,ski,mad,air,ulm".split(",")},
gh:{r:["com","edu","gov","org","mil"]},"عمان":{},to:{r:"com,gov,net,org,edu,mil".split(",")},kz:{r:"org,edu,net,gov,mil,com".split(",")},aq:{},dm:{r:["com","net","org","edu","gov"]},gi:{r:"com,ltd,gov,mod,edu,org".split(",")},mc:{r:["asso","tm"]},ar:{w:[""],e:"congresodelalengua3,gobiernoelectronico,promocion,retina,nacion,mecon,educ,nic,uba".split(",")},"مصر":{},md:{},as:{r:["gov"]},"do":{r:"art,com,edu,gob,gov,mil,net,org,sld,web".split(",")},tr:{w:[""],e:["nic"],r:["gov.nc"]},pa:{r:"nom,gob,com,org,sld,med,net,ing,abo,edu,ac".split(",")},
at:{r:"priv,info,biz,or,gv,co,ac".split(",")},gl:{},me:{r:"priv,edu,org,net,its,gov,ac,co".split(",")},"台湾":{},nz:{w:[""]},com:{r:"is-a-financialadvisor,is-a-personaltrainer,is-a-cubicle-slave,is-a-conservative,is-a-photographer,is-an-entertainer,saves-the-whales,is-an-accountant,issmarterthanyou,is-a-hard-worker,is-a-libertarian,is-into-cartoons,is-not-certified,est-mon-blogueur,is-a-landscaper,est-a-la-masion,est-a-la-maison,is-an-anarchist,is-a-bookkeeper,is-a-republican,is-with-theband,is-a-nascarfan,dyndns-at-work,is-a-socialist,is-an-engineer,dyndns-at-home,sells-for-less,is-a-therapist,is-a-bulls-fan,writesthisblog,is-a-anarchist,dyndns-server,space-to-rent,is-a-democrat,is-a-designer,dyndns-remote,is-an-actress,isa-hockeynut,is-into-games,dyndns-office,is-a-musician,est-le-patron,is-a-rockstar,is-into-anime,is-an-artist,is-a-blogger,is-a-teacher,teaches-yoga,is-a-student,is-a-caterer,is-certified,is-into-cars,is-a-painter,is-a-liberal,is-a-techie,is-a-player,dyndns-home,dyndns-free,dyndns-mail,dyndns-blog,dyndns-pics,sells-for-u,is-a-lawyer,is-uberleet,is-a-hunter,is-an-actor,dyndns-work,dyndns-wiki,is-a-doctor,doesntexist,likescandy,hobby-site,simple-url,is-a-llama,dyndns-web,operaunite,is-a-nurse,is-a-green,dyn-o-saur,homelinux,iamallama,likes-pie,is-a-chef,dyndns-ip,is-a-geek,dontexist,is-a-guru,dynalias,dnsalias,is-a-cpa,neat-url,isa-geek,homeunix,is-slick,servebbs,getmyip,from-wy,from-oh,from-wv,from-wi,from-wa,from-nv,is-leet,from-nj,from-nh,from-ne,from-vt,from-nd,from-va,from-nc,from-mt,from-ms,from-mo,from-mn,from-ut,from-mi,from-tx,from-md,from-ma,from-ky,from-ks,from-in,from-il,from-id,from-ia,from-hi,from-ga,from-fl,from-de,from-dc,from-ct,from-ca,from-ar,from-al,from-ak,from-tn,doomdns,from-sd,dnsdojo,from-sc,cechire,blogdns,from-ri,appspot,from-pr,from-pa,is-gone,from-or,from-ok,from-nm,selfip,gotdns,jpn,hu,qc,no,us,kr,sa,uy,uk,za,gr,ru,gb,eu,se,de,cn,br,ar".split(",")},
au:{w:[""],r:"act.edu,nsw.edu,tas.gov,qld.edu,qld.gov,tas.edu,vic.edu,act.gov,vic.gov,nt.gov,sa.edu,wa.gov,nt.edu,wa.edu,sa.gov,act,nsw,vic,qld,tas,sa,nt,wa".split(",")},gm:{},name:{r:["forgot.her","forgot.his"]},gn:{r:"net,com,edu,org,gov,ac".split(",")},mg:{r:"org,nom,gov,prd,mil,edu,com,tm".split(",")},zm:{w:[""]},"இலங்கை":{},"香港":{},tt:{r:"travel,museum,coop,aero,mobi,info,jobs,name,gov,pro,biz,net,org,com,int,edu,co".split(",")},aw:{r:["com"]},mh:{},ax:{},gp:{r:"asso,mobi,edu,net,org,com".split(",")},
pe:{r:"edu,gob,nom,mil,org,com,net".split(",")},sa:{r:"com,net,org,gov,med,pub,edu,sch".split(",")},ws:{r:"mypets,dyndns,gov,org,edu,net,com".split(",")},tv:{r:["better-than","worse-than","on-the-web","dyndns"]},ca:{r:"ab,bc,mb,nb,nf,nl,ns,nt,nu,on,pe,qc,sk,yk,gc".split(",")},gq:{},jm:{w:[""]},pf:{r:["com","org","edu"]},sb:{r:["com","edu","gov","net","org"]},"تونس":{},tw:{r:"商業,組織,網路,club,ebiz,game,idv,org,net,com,mil,gov,edu".split(",")},az:{r:"info,name,com,gov,org,edu,int,pro,mil,net,biz,pp".split(",")},
gr:{r:["com","edu","net","org","gov"]},mk:{r:"name,edu,net,org,gov,inf,com".split(",")},pg:{w:[""]},sc:{r:["com","gov","net","org","edu"]},aero:{r:"accident-investigation,passenger-association,accident-prevention,air-traffic-control,air-surveillance,groundhandling,civilaviation,certification,entertainment,workinggroup,championship,association,hanggliding,maintenance,marketplace,parachuting,paragliding,microlight,federation,navigation,ballooning,airtraffic,recreation,journalist,rotorcraft,government,conference,consultant,consulting,production,amusement,aerobatic,modelling,logistics,insurance,emergency,homebuilt,ambulance,aerodrome,equipment,skydiving,scientist,services,catering,research,aeroclub,magazine,exchange,software,engineer,aircraft,educator,journal,student,charter,leasing,trading,gliding,airline,control,freight,express,trainer,repbody,council,airport,broker,engine,agents,author,trader,safety,design,flight,group,cargo,union,press,pilot,media,works,show,taxi,club,dgca,crew,fuel,caa,res".split(",")},
local:{},gs:{},jo:{r:"name,sch,net,edu,org,gov,mil,com".split(",")},ml:{r:"presse,gouv,gov,edu,net,org,com".split(",")},ph:{r:"com,net,org,gov,mil,ngo,edu,i".split(",")},sd:{r:"info,edu,org,net,med,gov,com".split(",")},va:{},cc:{r:["game-server","ftpaccess","scrapping","myphotos"]},gt:{w:[""]},jp:{w:"kitakyushu,hiroshima,yamaguchi,yamanashi,kagoshima,tokushima,fukushima,nagasaki,shizuoka,wakayama,yamagata,hokkaido,kumamoto,yokohama,ishikawa,kawasaki,kanagawa,miyazaki,okayama,okinawa,ibaraki,niigata,tottori,tochigi,fukuoka,shimane,saitama,sapporo,miyagi,sendai,nagoya,nagano,toyama,aomori,kagawa,osaka,aichi,akita,iwate,chiba,gunma,shiga,ehime,kyoto,hyogo,kochi,tokyo,fukui,kobe,oita,gifu,saga,nara,mie".split(","),
e:"city.kitakyushu,city.hiroshima,pref.kagoshima,pref.tokushima,pref.hiroshima,pref.yamanashi,pref.yamaguchi,pref.fukushima,pref.wakayama,pref.yamagata,city.kawasaki,city.shizuoka,pref.hokkaido,pref.shizuoka,pref.nagasaki,pref.kanagawa,pref.miyazaki,pref.kumamoto,city.yokohama,pref.ishikawa,pref.tottori,pref.tochigi,pref.fukuoka,city.sapporo,pref.shimane,city.saitama,city.fukuoka,pref.ibaraki,city.okayama,pref.niigata,pref.saitama,pref.okayama,pref.okinawa,city.niigata,pref.aomori,city.nagoya,pref.nagano,pref.miyagi,city.sendai,pref.kagawa,pref.toyama,metro.tokyo,pref.gunma,pref.aichi,pref.hyogo,pref.fukui,pref.ehime,city.chiba,pref.shiga,pref.chiba,pref.kyoto,pref.akita,city.osaka,city.kyoto,pref.osaka,pref.iwate,pref.kochi,pref.nara,pref.oita,city.kobe,pref.gifu,pref.saga,pref.mie".split(","),
r:"ac,ad,co,ed,go,gr,lg,ne,or".split(",")},se:{r:"kommunalforbund,naturbruksgymn,komforb,komvux,lanbib,parti,press,brand,fhsk,sshn,fhv,org,bd,pp,tm,ac,fh,a,i,l,k,m,n,h,o,g,p,f,e,d,r,s,c,t,b,u,w,x,y,z".split(",")},"新加坡":{},tz:{r:"mil,ac,go,co,ne,or,sc".split(",")},cd:{r:["gov"]},gu:{w:[""]},mm:{w:[""]},"امارات":{},vc:{r:"com,net,org,gov,mil,edu".split(",")},dz:{r:"asso,edu,net,gov,org,com,pol,art".split(",")},mn:{r:["gov","edu","org"]},pk:{r:"info,gov,edu,org,fam,biz,web,net,gob,gok,gon,gop,gos,com".split(",")},
sg:{r:"com,net,org,gov,edu,per".split(",")},cf:{},gw:{},mo:{r:["com","net","org","edu","gov"]},pl:{r:"kazimierz-dolny,nieruchomosci,starostwo.gov,stalowa-wola,jelenia-gora,starachowice,swinoujscie,boleslawiec,prochowice,konskowola,malopolska,swiebodzin,kobierzyce,bieszczady,tarnobrzeg,ostrowwlkp,realestate,babia-gora,bialowieza,zgorzelec,bialystok,sosnowiec,przeworsk,bydgoszcz,dlugoleka,pomorskie,zachpomor,wloclawek,polkowice,kolobrzeg,ostroleka,ostrowiec,turystyka,wodzislaw,walbrzych,rawa-maz,katowice,podlasie,warszawa,zakopane,upow.gov,jaworzno,szczytno,szczecin,nowaruda,swidnica,limanowa,mazowsze,pruszkow,augustow,stargard,suwalki,beskidy,rzeszow,siedlce,bielawa,skoczow,wolomin,malbork,mragowo,cieszyn,czeladz,lezajsk,pomorze,legnica,gliwice,olsztyn,gniezno,gorlice,grajewo,opoczno,wroclaw,ostroda,klodzko,ketrzyn,tourism,karpacz,kartuzy,kaszuby,podhale,ug.gov,kalisz,pa.gov,warmia,glogow,poznan,wegrow,krakow,miasta,lebork,elblag,gdynia,gdansk,slupsk,lowicz,powiat,rybnik,bedzin,usenet,um.gov,mazury,mielec,mielno,pulawy,szkola,po.gov,travel,uw.gov,olecko,olkusz,sr.gov,so.gov,wielun,kepno,opole,olawa,mbone,jgora,ilawa,6bone,ustka,targi,naklo,sklep,tychy,zagan,zarow,wlocl,radom,turek,lukow,lubin,sanok,sejny,gmina,slask,lomza,bytom,czest,sopot,media,tgory,konin,kutno,zgora,info,mail,wroc,auto,lapy,priv,shop,nysa,agro,pisz,pila,aid,elk,irc,ngo,waw,gov,art,atm,sos,sex,rel,biz,com,gda,nom,net,med,mil,gsm,edu,org,pc,tm,co".split(",")},
sh:{},ve:{w:[""]},arpa:{r:"in-addr,e164,iris,ip6,uri,urn".split(",")},cg:{},mp:{},si:{},zw:{w:[""]},ch:{},gy:{r:["net","com","co"]},mq:{},pn:{r:["gov","net","edu","org","co"]},net:{r:"office-on-the,endofinternet,scrapper-site,at-band-camp,ham-radio-op,in-the-band,buyshouses,homelinux,kicks-ass,dontexist,is-a-geek,is-a-chef,dynathome,dynalias,thruhere,serveftp,isa-geek,homeunix,dnsalias,sells-it,broke-it,servebbs,from-az,from-ny,podzone,from-co,homeftp,does-it,dnsdojo,blogdns,gets-it,from-la,homeip,selfip,webhop,za,uk,se,gb".split(",")},
"한국":{},vg:{},ci:{r:"aéroport,presse,gouv,asso,net,org,int,edu,com,co,go,ac,or,md,ed".split(",")},mr:{r:["gov"]},sk:{},"ভারত":{},tel:{},ms:{},sl:{r:["com","net","edu","gov","org"]},__VERSION__:1325786179,ye:{w:[""]},vi:{r:["org","com","net","k12","co"]},ck:{w:[""]},id:{r:"web,sch,mil,net,go,or,co,ac".split(",")},mt:{w:[""]},sm:{},"భారత్":{},cl:{r:["gov","gob"]},ie:{r:["gov"]},la:{r:"info,edu,int,net,org,per,com,gov,c".split(",")},mu:{r:"com,net,org,gov,ac,co,or".split(",")},sn:{r:"perso,univ,gouv,edu,org,com,art".split(",")},
cm:{r:["gov"]},fi:{r:["aland","iki"]},lb:{r:["com","edu","gov","net","org"]},mv:{r:"museum,aero,name,coop,info,int,edu,gov,mil,com,biz,net,org,pro".split(",")},pr:{r:"isla,name,info,prof,com,edu,gov,biz,org,net,est,pro,ac".split(",")},so:{r:["com","net","org"]},coop:{},"المغرب":{},org:{r:"boldlygoingnowhere,endoftheinternet,is-a-celticsfan,is-a-linux-user,is-a-candidate,is-a-bruinsfan,endofinternet,sellsyourhome,is-very-sweet,is-a-patsfan,stuff-4-sale,is-very-nice,is-very-good,is-very-evil,misconfused,home.dyndns,is-very-bad,is-a-knight,is-a-soxfan,doesntexist,hobby-site,readmyblog,game-host,servegame,homelinux,go.dyndns,dontexist,is-a-geek,kicks-ass,is-a-chef,homeunix,serveftp,blogsite,dnsalias,isa-geek,is-found,dynalias,is-saved,servebbs,from-me,doomdns,is-lost,dnsdojo,blogdns,homedns,podzone,homeftp,gotdns,selfip,dyndns,dvrdns,webhop,za,us,ae".split(",")},
cn:{r:"网络,網絡,公司,net,gov,org,mil,edu,com,hl,ah,bj,cq,fj,gd,gs,gz,gx,ha,hb,he,hi,ac,hn,jl,js,jx,ln,nm,nx,qh,sc,sd,sh,sn,sx,tj,xj,xz,yn,zj,hk,mo,tw".split(",")},fj:{w:[""]},lc:{r:"com,net,gov,edu,org,co".split(",")},mw:{r:"museum,coop,org,com,net,biz,gov,int,edu,co,ac".split(",")},ps:{r:"edu,gov,sec,plo,com,org,net".split(",")},"рф":{},edu:{},co:{r:"arts,info,firm,int,gov,com,edu,mil,net,nom,org,rec,web".split(",")},fk:{w:[""]},mx:{r:["com","org","gob","edu","net"]},pt:{r:"nome,publ,int,edu,org,gov,com,net".split(",")},
vn:{r:"health,info,name,edu,gov,org,pro,biz,net,int,com,ac".split(",")},my:{r:"name,gov,org,net,edu,mil,com".split(",")},sr:{},"ਭਾਰਤ":{},fm:{},mz:{w:[""]},"السعودیة":{},cr:{r:"ac,co,ed,fi,go,or,sa".split(",")},pw:{r:"belau,ed,or,ne,go,co".split(",")},"قطر":{},fo:{},st:{r:"embaixada,consulado,principe,saotome,store,edu,com,net,org,gov,mil,co".split(",")},su:{},il:{w:[""]},li:{},py:{w:[""]},sv:{w:[""]},cu:{r:"com,edu,org,net,gov,inf".split(",")},im:{r:"ltd.co,plc.co,net,gov,nic,org,co,ac".split(",")},
jobs:{},ba:{r:"unsa,unbi,org,gov,mil,edu,com,net,co,rs".split(",")},"বাংলা":{},cv:{},fr:{r:"chirurgiens-dentistes,experts-comptables,huissier-justice,geometre-expert,veterinaire,pharmacien,chambagri,aeroport,notaires,assedic,medecin,avoues,avocat,presse,greta,port,asso,gouv,nom,prd,cci,com,tm".split(",")},"in":{r:"firm,gen,net,org,mil,ind,res,gov,edu,nic,ac,co".split(",")},lk:{r:"hotel,assn,ngo,int,com,org,edu,net,soc,web,ltd,sch,grp,gov".split(",")},vu:{},io:{r:["com"]},bb:{r:"store,info,edu,gov,com,net,org,biz".split(",")},
"ලංකා":{},ua:{r:"ivano-frankivsk,dnepropetrovsk,khmelnitskiy,zaporizhzhe,kirovograd,chernovtsy,sebastopol,chernigov,cherkassy,zhitomir,nikolaev,ternopil,uzhgorod,kherson,poltava,vinnica,kharkov,lugansk,donetsk,odessa,crimea,lutsk,rovno,lviv,kiev,sumy,gov,edu,net,org,com,kr,kv,mk,ks,od,lg,pl,km,kh,rv,if,dp,te,dn,cv,cn,vn,ck,zp,in,zt".split(",")},sy:{r:"edu,gov,net,mil,com,org".split(",")},re:{r:["asso","com","nom"]},cx:{r:["gov","ath"]},sz:{r:["org","ac","co"]},iq:{r:"gov,edu,mil,com,org,net".split(",")},
bd:{w:[""]},cy:{w:[""]},"சிங்கப்பூர்":{},ir:{r:"ايران,ایران,gov,sch,org,net,id,co,ac".split(",")},mil:{},be:{r:["ac"]},cz:{},yu:{w:[""]},"臺灣":{},"الجزائر":{},"中國":{},bf:{r:["gov"]},ec:{r:"info,pro,net,fin,k12,med,com,org,edu,gov,gob,mil".split(",")},is:{r:"net,com,edu,gov,org,int".split(",")},om:{w:[""],e:"nawrastelecom,statecouncil,rakpetroleum,omanmobile,mediaphone,omanpost,songfest,siemens,omantel,nawras".split(",")},bg:{r:"a,b,c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,x,y,z,0,1,2,3,4,5,6,7,8,9".split(",")},
it:{r:"andria-barletta-trani,monza-e-della-brianza,trani-andria-barletta,trani-barletta-andria,andria-trani-barletta,barletta-trani-andria,barlettatraniandria,tranibarlettaandria,andriatranibarletta,andriabarlettatrani,traniandriabarletta,monzaedellabrianza,carbonia-iglesias,iglesias-carbonia,iglesiascarbonia,carboniaiglesias,reggio-calabria,medio-campidano,campidano-medio,dell-ogliastra,campidanomedio,reggiocalabria,mediocampidano,vibo-valentia,massa-carrara,dellogliastra,monzaebrianza,urbino-pesaro,caltanissetta,carrara-massa,reggio-emilia,monza-brianza,ascoli-piceno,pesaro-urbino,monzabrianza,forli-cesena,carraramassa,olbia-tempio,pesarourbino,tempio-olbia,reggioemilia,ascolipiceno,urbinopesaro,cesena-forli,vibovalentia,massacarrara,alessandria,tempioolbia,cesenaforli,olbiatempio,forlicesena,campobasso,alto-adige,altoadige,ogliastra,catanzaro,frosinone,la-spezia,pordenone,benevento,agrigento,suedtirol,grosseto,cagliari,brindisi,oristano,trentino,florence,laspezia,avellino,verbania,vercelli,piacenza,macerata,siracusa,catania,bologna,cremona,mantova,crotone,sassari,messina,salerno,viterbo,sondrio,perugia,vicenza,palermo,taranto,ferrara,cosenza,caserta,livorno,firenze,pistoia,venezia,belluno,laquila,brescia,trapani,potenza,bolzano,isernia,pescara,trieste,imperia,bergamo,treviso,gorizia,ravenna,genova,ragusa,matera,biella,trento,balsan,torino,aquila,foggia,varese,modena,teramo,latina,venice,verona,arezzo,napoli,ancona,rimini,rovigo,chieti,padova,savona,naples,milano,novara,lucca,aosta,lecco,lecce,nuoro,prato,pavia,genoa,parma,rieti,fermo,aoste,udine,bozen,cuneo,turin,siena,milan,monza,terni,padua,como,enna,rome,bari,asti,lodi,pisa,roma,edu,gov,ot,no,mb,nu,mo,or,mi,me,pd,vs,pa,mt,pr,ms,pv,mn,pg,mc,pe,lu,lo,li,lc,pu,le,pc,lt,pi,sp,pt,aq,pn,is,pz,im,po,gr,rg,go,ra,ge,fr,rc,fc,fg,re,fi,ri,fm,rn,fe,en,rm,og,ro,cn,sa,kr,ss,cr,sv,cs,si,co,sr,ch,so,cz,ta,ct,ce,ci,cb,na,cl,te,ca,tr,br,bs,to,bz,tp,bo,bi,tn,bg,tv,bn,ts,bl,ud,bt,va,ba,av,ve,at,vb,ap,vc,ar,vr,ao,an,vv,al,vi,ag,vt".split(",")},
"ભારત":{},cat:{},bh:{r:["com","edu","net","org","gov"]},mobi:{},"срб":{},ug:{r:"co,ac,sc,go,ne,or".split(",")},bi:{r:["org","com","edu","or","co"]},ee:{r:"riik,com,edu,lib,med,gov,pri,aip,org,fie".split(",")},lr:{r:["com","edu","gov","org","net"]},"台灣":{},"ไทย":{},bj:{r:["barreau","asso","gouv"]},ls:{r:["org","co"]},"سوريا":{},eg:{r:"name,mil,eun,gov,edu,com,net,org,sci".split(",")},lt:{r:["gov"]},"中国":{},lu:{},"سورية":{},uk:{w:["sch",""],e:"national-library-scotland,british-library,parliament,police,icnet,nic,mod,jet,nls,nel,nhs,bl".split(",")},
gov:{},"int":{r:["eu"]},bm:{r:["com","edu","gov","net","org"]},lv:{r:"conf,mil,gov,org,edu,asn,net,com,id".split(",")},ro:{r:"store,firm,info,arts,com,nom,rec,org,www,nt,tm".split(",")},travel:{},bn:{w:[""]},"اليمن":{},"укр":{},bo:{r:"com,edu,gov,gob,mil,org,net,int,tv".split(",")},ke:{w:[""]},na:{r:"school,info,name,mobi,pro,com,org,mx,us,in,cc,tv,ws,dr,co,or,ca".split(",")},ly:{r:"com,net,gov,plc,org,sch,med,edu,id".split(",")},"ايران":{},info:{r:"barrell-of-knowledge,barrel-of-knowledge,here-for-more,knowsitall,groks-this,groks-the,for-our,dyndns,selfip,webhop".split(",")},
br:{r:"radio,vlog,wiki,taxi,flog,coop,blog,ntr,bio,ato,bmd,can,cim,cng,cnt,com,art,ecn,edu,emp,eng,esp,etc,eti,far,arq,zlg,fnd,fot,fst,g12,ggf,gov,imb,ind,inf,jor,jus,lel,mat,med,mil,mus,net,nom,not,adm,odo,org,ppg,pro,vet,psi,qsl,agr,rec,slg,srv,adv,teo,tmp,trd,tur,psc,tv,fm,am,b".split(",")},kg:{r:"org,net,com,edu,gov,mil".split(",")},nc:{r:["asso"]},rs:{r:"org,gov,edu,ac,co,in".split(",")}},Sa=require("page-mod"),Ua=require("widget"),M=require("tabs"),R=require("self").data;require("hotkeys");
var sa=require("simple-storage").storage,clipboard=require("clipboard"),Va=require("context-menu"),za=require("windows").browserWindows,Wa=i,Y=[];function Ja(b){for(var c=[],a=0;a<Y.length;++a)Y[a].tab==b&&c.push(Y[a]);return c}
function wa(b,c,a,d){b||(b="logins");c||(c=g);c="tab="+b+"&locked="+(c?"yes":"no")+"&fillLoginHotKeyUsed="+(a?"yes":"no");d&&(c=c+"&fillLoginUuid="+d);var e=require("panel").Panel({contentURL:R.url("ui/popup.html?"+c),contentScriptWhen:"ready",contentScriptFile:[R.url("src/ext/json2-min.js"),R.url("src/ext/sjcl.js"),R.url("src/ext/jquery-1.7.1.min.js"),R.url("src/popup.min.js"),R.url("src/ext/jquery.tools-1.2.5.min.js")],onShow:function(){this.port.emit("show",{url:M.activeTab.url,tab:b,locked:C.a(),
settings:B.d(),troubleshooting:L.c()?"no":"yes"})},onHide:function(){this.port.emit("hide",{})}});e.width=300;e.height=312;e.port.on("error",function(a){console.error("[FIREFOX] Error: "+a)});e.port.on("perform",function(a){try{X(e,a.command,a.params,function(b){e.port.emit("callback",{uuid:a.uuid,result:b})})}catch(b){n(b)}});e.port.on("message",function(a){W(M.activeTab,a.name,a.message,i);"beginManualSave"!==a.name&&"copyToClipboard"!==a.name&&e.hide()});return e}
var Z={W:function(b){var c=b.indexOf("onepasswdfill=");if(0>=c)return i;var a=b.substr(c+14),b=b.substring(0,c-1);return 1>a.length?i:{uuid:a,url:b}},Ka:function(){if(M&&M.activeTab&&M.activeTab.url){var b=Z.W(M.activeTab.url);b&&(ya(b.url),J.i(b.uuid,j,"CurrentTab"))}},observe:function(b){var c=b.QueryInterface(Ci.nsIHttpChannel),a=Z.W(c.URI.spec);if(a)b.cancel(0),(b=Z.Ua(c))?b.location=a.url:ya(a.url),J.i(a.uuid,j,"CurrentTab")},Ua:function(b){try{var c=b.notificationCallbacks?b.notificationCallbacks:
b.loadGroup.notificationCallbacks;return!c?i:c.getInterface(Ci.nsIDOMWindow)}catch(a){return i}},ja:function(){return Cc["@mozilla.org/observer-service;1"].getService(Ci.nsIObserverService)},vb:function(){Z.ja().addObserver(Z,"http-on-modify-request",j)},bc:function(){Z.ja().Zb(Z,"http-on-modify-request")}};
exports.main=function(){Z.vb();setTimeout(function(){Z.Ka()},500);require("toolbarbutton").ToolbarButton({id:"onepassword-toolbar-button",label:"1Password",image:R.url("images/toolbar-firefox.png"),onCommand:function(b){wa("logins",C.a(),j,i).show(b)}}).moveTo({toolbarID:"nav-bar",forceMove:j});Sa.PageMod({include:["*"],contentScriptWhen:"ready",contentScriptFile:[R.url("src/end.min.js"),R.url("src/ext/json2-min.js")],onAttach:function(b){Y.push(b);b.on("detach",function(){var b=Y,a=b.indexOf(this);
-1!=a&&b.splice(a,1)});b.port.on("message",function(c){W(b.tab,c.name,c.message,i)});b.port.on("perform",function(c){try{X(b,c.command,c.params,function(a){b.port.emit("callback",{uuid:c.uuid,result:a})})}catch(a){n(a)}})}});Ua.Widget({id:"show-onepassword-popup",label:"Show 1Password",contentURL:R.url("ui/widget.html"),panel:wa("logins",C.a(),j,i),width:24});M.on("activate",function(){Q.f()});M.on("ready",function(){Q.f()})};
exports.onUnload=function(b){"uninstall"===b&&(b=Cc["@mozilla.org/file/directory_service;1"].getService(Ci.nsIProperties).get("ProfD",Ci.nsIFile),b.append(".."),b.append("OnePassword.sqlite"),b.remove(j))};
var Q=function(){function b(b,a){var d=require("panel").Panel({contentURL:R.url("ui/autosave3.html?locked="+(b?"yes":"no")+"&autosaveId="+a),contentScriptWhen:"start",contentScriptFile:[R.url("src/ext/json2-min.js"),R.url("src/ext/sjcl.js"),R.url("src/ext/jquery-1.7.1.min.js"),R.url("src/autosave3.min.js")],onShow:function(){this.port.emit("show",{locked:C.a()})},onHide:function(){this.port.emit("hide",{})}});d.width=270;d.height=120;d.port.on("error",function(a){console.log("[FIREFOX] Autosave Error: "+
a)});d.port.on("perform",function(a){try{"hidePopup"==a.command?d.hide():X(d,a.command,a.params,function(b){d.port.emit("callback",{uuid:a.uuid,result:b})})}catch(b){n(b)}});d.port.on("message",function(a){W(M.activeTab,a.name,a.message,i)});return d}return{Kb:function(c){var a=i;try{var d=Cc["@mozilla.org/appshell/window-mediator;1"].getService(Ci.nsIWindowMediator);if(d){var e=d.getMostRecentWindow("navigator:browser");e&&e.document&&(a=e.document.getElementById("onepassword-toolbar-button"))}}catch(f){n(f)}b(C.a(),
c).show(a)},Ib:function(b){try{var a=Cc["@mozilla.org/appshell/window-mediator;1"].getService(Ci.nsIWindowMediator);if(a)for(var d=a.getEnumerator("navigator:browser");d.hasMoreElements();){var e=d.getNext();e&&e.document&&(tbb=e.document.getElementById("onepassword-toolbar-button"))&&tbb.getAttribute("image")!=b&&tbb.setAttribute("image",b)}}catch(f){n(f)}},f:function(){Wa&&Wa.destroy();Wa=Va.Item({label:"1Password",contentScript:"self.on(\"click\", function (node, data) {   self.postMessage({'name':'click', 'data':node});  });  self.on(\"context\", function (node) {\t   self.postMessage({'name':'showing'});     return true;  });",
onMessage:function(b){b=b.name;if("click"===b)wa(i,C.a(),j,i).show();else if("showing"===b)this.label=C.a()?"Unlock 1Password":"1Password"}})},Ub:function(b){if(!b||""===b)return[];for(var a=[],b=J.K(b),d=0,e=b.length;d<e;++d){var f=b[d];a.push(Va.Item({label:w(f.overview.title),data:f.uuid}))}return a},C:function(){var b=[];require("passwords").search({onComplete:function(a){a.forEach(function(a){if(a.url&&"chrome://weave"!==a.url){var e=[],f={},h={};a.usernameField&&(f.name=a.usernameField);a.passwordField&&
(h.name=a.passwordField);a.username&&(f.value=a.username);a.password&&(h.value=a.password);f.type="T";h.type="P";f.designation="username";h.designation="password";e.push(f);e.push(h);f={type_name:"webforms.WebForm",overview:{}};f.overview.location=a.url;f.overview.title=z.A(a.url);f.secureContents={};f.secureContents.fields=e;b.push(a.url);Da(f,function(a){if(a.error)return alert(a.error),j})}});a=a="ui/importResults.html";a=u(a);a+="?numImported="+b.length+"&imported="+escape(escape(JSON.stringify(b)));
J.m(a);J.removePopover()}})}}}();
